@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: icontextoestudio.cpp 3645 2011-04-04 09:21:08Z tovar $
+ *  $Id: icontextoestudio.cpp 3995 2011-07-13 18:24:42Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -11,25 +11,29 @@
  *
  */
 #include <wx/mstream.h>
-#include <wx/config.h>
+#include <main/controllers/configurationcontroller.h>
 #include <wx/filename.h>
 #include <wx/xml/xml.h>
+#include <wx/file.h>
 
 #include <api/globals.h>
+#include <api/ientorno.h>
 #include <api/ivista.h>
+#include <api/icontextoestudio.h>
 #include <api/imodelointegracion.h>
-#include <api/icontroladorimportacionpacs.h>
-#include <api/idicommanager.h>
-#include <api/idicomizador.h>
+
+#include <api/dicom/idicomizador.h>
+#include <api/dicom/idicommanager.h>
+
+#include <api/controllers/ipacscontroller.h>
+#include <api/icontroladorhistorial.h>
 #include <api/icontroladorherramientas.h>
 #include <api/icontroladorlog.h>
 
 #include <main/controllers/controladorcarga.h>
 #include <main/controllers/controladorlog.h>
 
-#include "icontroladorhistorial.h"
-#include "ientorno.h"
-#include "icontextoestudio.h"
+
 
 #undef __DEPRECATED
 #include <vtkginkgoimageviewer.h>
@@ -191,6 +195,7 @@ void GNC::GCS::IContextoEstudio::SetIndiceActivo(int indice)
 
 	IndiceFicheroActivo = indice;
 	Loader->SetInput(fichero.RutaImagen);
+	Loader->UpdateInformation();
 	double spacing[3] = {1.0f, 1.0f, 1.0f};
 	GetSpacingActiva(spacing[0], spacing[1], spacing[2]);
 	Loader->SetOutputSpacing(spacing);
@@ -547,16 +552,12 @@ int GNC::GCS::IContextoEstudio::GetTSizeActiva()
 const std::string GNC::GCS::IContextoEstudio::GetNombreMedico()
 {
 	std::string nombre ("");
-	wxString wxTmp;
 	if(ModeloIntegracion.IsValid()) {
 		std::ostringstream ostr;
 		ostr<<ModeloIntegracion->Medico.apellido1 << '^' << ModeloIntegracion->Medico.apellido2 << '^' << ModeloIntegracion->Medico.nombre;
 		nombre = ostr.str();
 	} else {
-		wxConfigBase::Get()->Read(wxT("/GinkgoCore/Estacion/NombreMedico"),&wxTmp,wxEmptyString);
-		if(wxTmp != wxEmptyString){
-			nombre = std::string(wxTmp.ToUTF8());
-		}
+		GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion","NombreMedico",nombre);
 	}
 	return nombre;
 }
@@ -565,14 +566,10 @@ const std::string GNC::GCS::IContextoEstudio::GetNombreMedico()
 const std::string GNC::GCS::IContextoEstudio::GetNombreCentro()
 {
 	std::string nombre ("");
-	wxString wxTmp;
 	if(ModeloIntegracion.IsValid()) {
 		nombre = ModeloIntegracion->Medico.nombreCentro;
 	} else {
-		wxConfigBase::Get()->Read(wxT("/GinkgoCore/Estacion/CentroNombre"),&wxTmp,wxEmptyString);
-		if(wxTmp != wxEmptyString){
-			nombre = std::string(wxTmp.ToUTF8());
-		}
+		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",nombre);
 	}
 	return nombre;
 }
@@ -719,19 +716,19 @@ bool GNC::GCS::IContextoEstudio::GuardarUnDiagnostico()
 			}
 		}
 
-		GIL::DICOM::IDICOMImg2DCM* pDicomizador = Entorno->GetControladorImportacionPACS()->CrearInstanciaDeImportacion();
+		GIL::DICOM::IDICOMImg2DCM* pDicomizador = Entorno->GetPACSController()->CrearInstanciaDeImportacion();
 		std::list<GnkPtr<GIL::DICOM::TipoPrivateTags> > listaTagsPrivados;
 		listaTagsPrivados.push_back(pTagsPrivados);
 
 		correcto = correcto && CallbackPreCrearDiagnostico(0, &baseSR, listaTagsPrivados);	//se deja a las clases hijas que indtroduzcan los tags que deseen
 
 		pDicomizador->CrearSRDoc(stdPathTmp,baseSR,listaTagsPrivados);
-		Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeImportacion(pDicomizador);
+		Entorno->GetPACSController()->LiberarInstanciaDeImportacion(pDicomizador);
 
 		//se le el uid de serie, estudio y paciente para copiarlo al dicomdir
-		GIL::DICOM::IDICOMManager* pDICOMManager= Entorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+		GIL::DICOM::IDICOMManager* pDICOMManager= Entorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 		pDICOMManager->CargarFichero(stdPathTmp, *pTagDiagnostico);
-		Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+		Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 
 		//si el uid del estudio de diagnosticos no esta establecido, se establece
 		if(UIDEstudioDiagnostico == std::string("")) {
@@ -744,7 +741,7 @@ bool GNC::GCS::IContextoEstudio::GuardarUnDiagnostico()
 		pTagDiagnostico->getTag(std::string("0020|000e"),uidSerie);
 		pTagDiagnostico->getTag(std::string("0008|0018"),uidImagen);
 
-		Entorno->GetControladorImportacionPACS()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen,Ficheros[0]->RutaDiagnostico);
+		Entorno->GetPACSController()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen,Ficheros[0]->RutaDiagnostico);
 
 		correcto  = correcto && wxCopyFile(pathTmp,FROMPATH( Ficheros[0]->RutaDiagnostico ));
 
@@ -771,7 +768,7 @@ bool GNC::GCS::IContextoEstudio::GuardarUnDiagnostico()
 			}
 		}
 
-		GIL::DICOM::IDICOMManager*	pDICOMManager= Entorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+		GIL::DICOM::IDICOMManager*	pDICOMManager= Entorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 		GIL::DICOM::TipoJerarquia base;
 		pDICOMManager->CargarFichero(Ficheros[0]->RutaDiagnostico, base);
 
@@ -781,7 +778,7 @@ bool GNC::GCS::IContextoEstudio::GuardarUnDiagnostico()
 		correcto = correcto && CallbackPreGuardarDiagnostico(0,pDICOMManager); //se ofrece la posibilidad de insertar mas cosas
 		correcto = correcto && pDICOMManager->AlmacenarFichero(Ficheros[0]->RutaDiagnostico);
 		//se libera el dicommanager
-		Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+		Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 	}
 
 	return correcto;
@@ -817,13 +814,13 @@ bool GNC::GCS::IContextoEstudio::GuardarNDiagnosticos()
 		pTagDiagnostico->tags[std::string("0008|0032")] = wxDateTime::Now().Format(wxT("%H%M%S")).ToUTF8(); //hora del imagen
 
 		//institucion
-		wxString wxTmp;
+		std::string strTmp;
 		if(ModeloIntegracion.IsValid()) {
 			pTagDiagnostico->tags[std::string("0008|0080")] = ModeloIntegracion->Medico.nombreCentro;
 		} else {
-			wxConfigBase::Get()->Read(wxT("/GinkgoCore/Estacion/CentroNombre"),&wxTmp,wxEmptyString);
-			if(wxTmp != wxEmptyString){
-				pTagDiagnostico->tags[std::string("0008|0080")] = std::string(wxTmp.ToUTF8());
+			GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",strTmp);
+			if(strTmp.size() != 0){
+				pTagDiagnostico->tags[std::string("0008|0080")] = strTmp;
 			}
 		}
 
@@ -851,19 +848,19 @@ bool GNC::GCS::IContextoEstudio::GuardarNDiagnosticos()
 				baseSR.AddReference(sopClassUID,sopInstanceUID);
 			}
 
-			GIL::DICOM::IDICOMImg2DCM* pDicomizador = Entorno->GetControladorImportacionPACS()->CrearInstanciaDeImportacion();
+			GIL::DICOM::IDICOMImg2DCM* pDicomizador = Entorno->GetPACSController()->CrearInstanciaDeImportacion();
 			std::list<GnkPtr<GIL::DICOM::TipoPrivateTags> > listaTagsPrivados;
 			listaTagsPrivados.push_back(pTagsPrivados);
 
 			correcto = correcto && CallbackPreCrearDiagnostico(i, &baseSR, listaTagsPrivados);	//se deja a las clases hijas que indtroduzcan los tags que deseen
 
 			pDicomizador->CrearSRDoc(stdPathTmp,baseSR,listaTagsPrivados);
-			Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeImportacion(pDicomizador);
+			Entorno->GetPACSController()->LiberarInstanciaDeImportacion(pDicomizador);
 
 			//se le el uid de serie, estudio y paciente para copiarlo al dicomdir
-			GIL::DICOM::IDICOMManager* pDICOMManager= Entorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+			GIL::DICOM::IDICOMManager* pDICOMManager= Entorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 			pDICOMManager->CargarFichero(stdPathTmp, *pTagDiagnostico);
-			Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+			Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 
 			//si el uid del estudio de diagnosticos no esta establecido, se establece
 			if(UIDEstudioDiagnostico == std::string("")) {
@@ -876,7 +873,7 @@ bool GNC::GCS::IContextoEstudio::GuardarNDiagnosticos()
 			pTagDiagnostico->getTag(std::string("0020|000e"),uidSerie);
 			pTagDiagnostico->getTag(std::string("0008|0018"),uidImagen);
 
-			Entorno->GetControladorImportacionPACS()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen,Ficheros[i]->RutaDiagnostico);
+			Entorno->GetPACSController()->GetRutaImagen(uidPaciente,UIDEstudioDiagnostico,uidSerie,uidImagen,Ficheros[i]->RutaDiagnostico);
 
 			correcto  = correcto && wxCopyFile(pathTmp,FROMPATH( Ficheros[i]->RutaDiagnostico ));
 
@@ -887,7 +884,7 @@ bool GNC::GCS::IContextoEstudio::GuardarNDiagnosticos()
 			wxRmDir( stdDirPathTmp.c_str() );
 			#endif
 		} else {
-			GIL::DICOM::IDICOMManager*	pDICOMManager= Entorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+			GIL::DICOM::IDICOMManager*	pDICOMManager= Entorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 			GIL::DICOM::TipoJerarquia base;
 			pDICOMManager->CargarFichero(Ficheros[i]->RutaDiagnostico, base);
 
@@ -897,7 +894,7 @@ bool GNC::GCS::IContextoEstudio::GuardarNDiagnosticos()
 			correcto = correcto && CallbackPreGuardarDiagnostico(i,pDICOMManager); //se ofrece la posibilidad de insertar mas cosas
 			correcto = correcto && pDICOMManager->AlmacenarFichero(Ficheros[i]->RutaDiagnostico);
 			//se libera el dicommanager
-			Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+			Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 		}
 
 		Ficheros[i]->Modificado = false;
@@ -915,7 +912,7 @@ void GNC::GCS::IContextoEstudio::CreateLoader()
 void GNC::GCS::IContextoEstudio::SetTagsDiagnostico( GIL::DICOM::TipoJerarquia& baseSR, GnkPtr<GIL::DICOM::TipoJerarquia> pTagDiagnostico)
 {
 	//todos los tags del paciente...
-	for(GIL::DICOM::TipoJerarquia::ListaTags::iterator it = pTagDiagnostico->tags.begin(); it!= pTagDiagnostico->tags.end(); it++){
+	for(GIL::DICOM::ListaTags::iterator it = pTagDiagnostico->tags.begin(); it!= pTagDiagnostico->tags.end(); it++){
 		//paciente, estudio
 		if((*it).first.substr(0,4) == "0010"){
 			baseSR.tags[(*it).first] = (*it).second;
@@ -935,13 +932,14 @@ void GNC::GCS::IContextoEstudio::SetTagsDiagnostico( GIL::DICOM::TipoJerarquia&
 		baseSR.tags[std::string("0020|000d")] = UIDEstudioDiagnostico;		//uid estudio diagnostico
 	}
 
-	baseSR.tags[std::string("0018|1030")] = Modulo->GetUID();				//uid importador que crea la serie
-	baseSR.tags[std::string("0008|0021")] = pTagDiagnostico->tags["0008|0021"]; //fecha de la serie
-	baseSR.tags[std::string("0008|0031")] = pTagDiagnostico->tags["0008|0031"]; //hora de la serie
-	baseSR.tags[std::string("0008|0020")] = pTagDiagnostico->tags["0008|0020"]; //fecha del Estudio
-	baseSR.tags[std::string("0008|0030")] = pTagDiagnostico->tags["0008|0030"]; //hora del Estudio
-	baseSR.tags[std::string("0008|0022")] = pTagDiagnostico->tags["0008|0022"]; //fecha del imagen
-	baseSR.tags[std::string("0008|0032")] = pTagDiagnostico->tags["0028|0032"]; //hora del imagen
+	//TODO ESTO HAY QUE ELIMINARLO... PORQUE ESTA PREPARADO PARA APRIMARIA
+	baseSR.tags[std::string("0018|1030")] = "METAEMOTION GINKGO RX";				//uid importador que crea la serie
+	baseSR.tags[std::string("0008|0021")] = wxDateTime::Now().Format(wxT("%Y%m%d")).ToUTF8(); //fecha de la serie
+	baseSR.tags[std::string("0008|0031")] = wxDateTime::Now().Format(wxT("%H%M%S")).ToUTF8(); //hora de la serie
+	baseSR.tags[std::string("0008|0020")] = wxDateTime::Now().Format(wxT("%Y%m%d")).ToUTF8(); //fecha de la estudio
+	baseSR.tags[std::string("0008|0030")] = wxDateTime::Now().Format(wxT("%H%M%S")).ToUTF8(); //hora de la estudio
+	baseSR.tags[std::string("0008|0022")] = wxDateTime::Now().Format(wxT("%Y%m%d")).ToUTF8(); //fecha de la imagen
+	baseSR.tags[std::string("0008|0032")] = wxDateTime::Now().Format(wxT("%H%M%S")).ToUTF8(); //hora de la imagen
 	baseSR.tags[std::string("0008|0080")] = pTagDiagnostico->tags["0008|0080"];//centro
 	baseSR.tags[std::string("0008|0090")] = pTagDiagnostico->tags["0008|0090"];//medico
 	baseSR.tags[std::string("0008|0050")] = pTagDiagnostico->tags["0008|0050"];//accession number
@@ -1076,9 +1074,9 @@ void GNC::GCS::IContextoEstudio::CargarMetaInfo(const int indice)
 		Ficheros[indice]->MetaInfo = new GIL::DICOM::TipoMetaInfo();
 		
 		GIL::DICOM::IDICOMManager*	pDICOMManager;
-		pDICOMManager= Entorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+		pDICOMManager= Entorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 		pDICOMManager->CargarMetaInfo(Ficheros[indice]->RutaImagen, *Ficheros[indice]->MetaInfo);
-		Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+		Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 	}
 	UnLock("CargarMetaInfo");
 }
@@ -1099,7 +1097,7 @@ void GNC::GCS::IContextoEstudio::CargarTagsImagen(const int indice)
 		Ficheros[indiceDiagnostico]->TagsPrivados = new GIL::DICOM::TipoPrivateTags(UID_TAGS_PRIVADOS_COMUNES);
 
 		GIL::DICOM::IDICOMManager*	pDICOMManager;
-		pDICOMManager= Entorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+		pDICOMManager= Entorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 		pDICOMManager->CargarFichero(Ficheros[indice]->RutaImagen, *Ficheros[indice]->TagsImagen);
 
 		//se busca el fichero de diagnostico...
@@ -1117,11 +1115,11 @@ void GNC::GCS::IContextoEstudio::CargarTagsImagen(const int indice)
 		if(wxFileExists(FROMPATH(pathAbsoluto)))
 		{
 			//leemos los tags privados del diagnostico
-			Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+			Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 
 			Ficheros[indiceDiagnostico]->RutaDiagnostico = pathAbsoluto;
 
-			pDICOMManager= Entorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+			pDICOMManager= Entorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 			pDICOMManager->CargarFichero(Ficheros[indiceDiagnostico]->RutaDiagnostico, *Ficheros[indiceDiagnostico]->TagsDiagnostico);
 
 			//si el uid del estudio de diagnosticos no esta establecido, se establece
@@ -1131,14 +1129,14 @@ void GNC::GCS::IContextoEstudio::CargarTagsImagen(const int indice)
 
 			pDICOMManager->CargarTagsPrivados(*Ficheros[indiceDiagnostico]->TagsPrivados);
 			CallbackCargarTagsImagen(indice, pDICOMManager);
-			Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+			Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 		} else {
 			//leemos los tags privados de la imagen...
 			pDICOMManager->CargarTagsPrivados(*Ficheros[indiceDiagnostico]->TagsPrivados);
 			CallbackCargarTagsImagen(indice, pDICOMManager);
 
 			(*Ficheros[indiceDiagnostico]->TagsDiagnostico) = (*Ficheros[indice]->TagsImagen);
-			Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+			Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 		}
 	}
 
@@ -1147,9 +1145,9 @@ void GNC::GCS::IContextoEstudio::CargarTagsImagen(const int indice)
 		Ficheros[indice]->TagsImagen = new GIL::DICOM::TipoJerarquia();
 
 		GIL::DICOM::IDICOMManager*	pDICOMManager;
-		pDICOMManager= Entorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+		pDICOMManager= Entorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 		pDICOMManager->CargarFichero(Ficheros[indice]->RutaImagen, *Ficheros[indice]->TagsImagen);
-		Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+		Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 	}
 
 
