@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: initwx.cpp 3787 2011-04-29 06:38:01Z tovar $
+ *  $Id: initwx.cpp 3910 2011-07-01 10:12:00Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -34,9 +34,8 @@
 #include <wx/msgout.h>
 #include <wx/msgdlg.h>
 #include <wx/dcmemory.h>
-#include <wx/confbase.h>
+#include <main/controllers/configurationcontroller.h>
 #include <wx/filename.h>
-#include <wx/fileconf.h>
 #include <wx/stdpaths.h>
 #include <wx/dir.h>
 #include <wx/sysopt.h>
@@ -76,7 +75,7 @@
 #include <api/globals.h>
 #include <api/imodulo.h>
 #include <api/icontroladormodulo.h>
-#include <api/internacionalizacion.h>
+#include <api/dicom/idicomconformance.h>
 #include <eventos/eventosginkgo.h>
 
 
@@ -86,7 +85,7 @@
 #include <main/controllers/controladorvistas.h>
 #include <main/controllers/controladorcomandos.h>
 #include <main/controllers/controladorherramientas.h>
-#include <main/controllers/controladorimportacionpacs.h>
+#include <main/controllers/pacscontroller.h>
 #include <main/controllers/controladoreventos.h>
 #include <main/controllers/controladorcarga.h>
 #include <main/controllers/controladorhl7.h>
@@ -101,6 +100,7 @@
 #include <main/controllers/controladorautenticacion.h>
 #include <main/tools/herramientascore.h>
 #include <main/controllers/xmlrpccontroller.h>
+#include <main/controllers/configurationcontroller.h>
 
 #include <main/gui/mainwindow/ventanaprincipal.h>
 
@@ -133,21 +133,21 @@ void RedirectIOToConsole()
 	long hConHandle = _open_osfhandle(lStdHandle, _O_TEXT);
 	fp = _fdopen(hConHandle, "w");
 	*stdout = *fp;
-	setvbuf(stdout, NULL, _IONBF, 0);
+	//setvbuf(stdout, NULL, _IONBF, 0);
 
 	// redirect unbuffered STDIN to the console
 	lStdHandle = (long) GetStdHandle(STD_INPUT_HANDLE);
 	hConHandle = _open_osfhandle(lStdHandle, _O_TEXT);
 	fp = _fdopen(hConHandle, "r");
 	*stdin = *fp;
-	setvbuf(stdin, NULL, _IONBF, 0);
+	//setvbuf(stdin, NULL, _IONBF, 0);
 
 	// redirect unbuffered STDERR to the console
 	lStdHandle = (long) GetStdHandle(STD_ERROR_HANDLE);
 	hConHandle = _open_osfhandle(lStdHandle, _O_TEXT);
 	fp = _fdopen(hConHandle, "w");
 	*stderr = *fp;
-	setvbuf(stderr, NULL, _IONBF, 0);
+	//setvbuf(stderr, NULL, _IONBF, 0);
 
 	// make cout, wcout, cin, wcin, wcerr, cerr, wclog and clog
 	// point to console as well
@@ -199,28 +199,6 @@ bool Ginkgo::OnInit()
 
 	setlocale(LC_NUMERIC, "C");
 
-	#if !defined(_WINDOWS)
-	if (argc > 1) {
-		for (int i = 1; i < argc; i++) {
-			wxString param(argv[i]);
-
-			if ( param.CmpNoCase(wxT("-version")) == 0 || param.CmpNoCase(wxT("--version")) == 0 || param.CmpNoCase(wxT("-v")) == 0 ) {
-
-				int version = 0;
-				int subversion = 0;
-				int release = 0;
-				int build = 0;
-				std::string codename;
-
-				GNC::Entorno::Instance()->GetGinkgoVersionAsTuple(&version, &subversion, &release, &build, &codename);
-				GNC::Entorno::FreeInstance();
-				std::cout << version << "." << subversion << "." << release << "." << build << " " << codename.c_str() << std::endl;
-				return false;
-			}
-		}
-	}
-	#endif
-
 #if defined(__WXOSX__)
 	m_Inicializado = false;
 #endif
@@ -239,8 +217,6 @@ bool Ginkgo::OnInit()
 	wxLog *logger = new wxLogStderr();
 	wxLog::SetActiveTarget(logger);
 	wxSQLite3Database::InitializeSQLite();
-	//leer config
-	SetConfig();
 
 	WriteHeaderLog();
 
@@ -307,7 +283,7 @@ bool Ginkgo::OnInit()
 		//nos salimos limpiamente sin dejar leaks
 		GNC::GCS::ControladorLog::FreeInstance();
 		GNC::Entorno::FreeInstance();
-		delete wxConfigBase::Set(NULL);
+		GNC::GCS::ConfigurationController::FreeInstance();
 		return false;
 	}
 	#endif
@@ -324,7 +300,7 @@ bool Ginkgo::OnInit()
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.update", _Std("Program Updates"), "check_updates", _Std("Warn about newest Ginkgo CADx updates"), false, "http://updates.ginkgo-cadx.com/version.xml", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.update", _Std("Program Updates"), "update_period", _Std("Update period (days)"), false, "2", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.seguridad",_Std("Security"), "setup_security", _Std("Setup Security"), false, "", false);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.adquisicion",_Std("Adquisition"), "pacs", _Std("Acquire images from PACS"),false, "", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.adquisicion",_Std("Acquisition"), "pacs", _Std("Acquire images from PACS"),false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"subir pacs",_Std("Upload images to a PACS server"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"configuracion",_Std("Settings menu"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.menu",_Std("Tools"),"filtrado",_Std("Filter menu"), true, "", false);
@@ -334,9 +310,9 @@ bool Ginkgo::OnInit()
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "patient_scope", _Std("Restrict search over selected patient"), false, "", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "study_size", _Std("Restrict study retrieval by maximum size (KB)"), false, "16384", false);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.pacs.limits", _Std("PACS Limits"), "force_lossless", _Std("Force lossless when upload"), false, "", false);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Importation"), "quality", _Std("Set compression, 0 implies no compression (0..14)"), false, "1", true);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Importation"), "codec", _Std("Recompression Codec (0=JPEG Baseline(default), 1=JPEG Progressive, 2=JPEG Lossless)"), false, "0", true);
-	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Importation"), "mantener", _Std("Don't change image codec (if possible)"), false, "", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "quality", _Std("Set compression, 0 implies no compression (0..14)"), false, "1", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "codec", _Std("Recompression Codec (0=JPEG Baseline(default), 1=JPEG Progressive, 2=JPEG Lossless)"), false, "0", true);
+	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.importacion", _Std("Import"), "mantener", _Std("Don't change image codec (if possible)"), false, "", true);
 
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.hl7", _Std("HL7 Service"), "autostart", _Std("Automatically start HL7 Sender service"), false, "", true);
 	GNC::GCS::ControladorPermisos::Instance()->AddDefinicionPermiso("core.integracion", _Std("XML dicomization"), "send_message", _Std("Send Hl7 message when importing"), false, "", true);
@@ -424,6 +400,14 @@ bool Ginkgo::OnInit()
 		DoProgress(wxString(_("Loading plugins ...")));
 		LoadPlugins();
 
+		DoProgress(wxString(_("Loading resources ...")));
+		GIL::DICOM::Conformance::Load();
+
+		DoProgress(wxString(_("Starting services...")));
+		//TODO DESCOMENTAR CUANDO FUNCIONE EL MOVE GIL::DICOM::PACSController::Instance()->StartService();
+
+		DoProgress(wxString(_("Starting tools...")));
+
 		
 		GNC::ControladorHerramientas* cH = GNC::ControladorHerramientas::Instance();
 		try {
@@ -461,25 +445,19 @@ bool Ginkgo::OnInit()
 			//carga de permisos definidos en licencia (privados)
 			GNC::GCS::ControladorPermisos::Instance()->CargarXMLPermisos(permisos,true);
 
-			//ahora leemos el xml de configuracion que puede star en el ini
-			wxConfigBase * config = wxConfigBase::Get();
-			config->SetPath(wxT("/GinkgoCore/Profiles"));
-			wxString str;
-			bool aplicar;
-			long dummy;
+			GNC::GCS::ConfigurationController::TListGroups profiles;
+			GNC::GCS::ConfigurationController::Instance()->readGroupGeneral("/GinkgoCore/Profiles", profiles);
 
-			bool bCont = config->GetFirstGroup(str, dummy);
-			while ( bCont ) {
-				config->SetPath(str);
-				config->Read(wxT("Apply"),&aplicar);
-				if(aplicar) {
-					config->Read(wxT("XML"),&str);
-					std::string xml(str.ToUTF8());
-					GNC::GCS::ControladorPermisos::Instance()->CargarXMLPermisos(xml,false);
-					break;
+			for (GNC::GCS::ConfigurationController::TListGroups::iterator it = profiles.begin(); it != profiles.end(); ++it) {
+				bool value;
+				(*it).readBoolValue("Apply",value, false);
+				if (value) {
+					std::string xml;
+					if ((*it).readStringValue("XML", xml)) {
+						GNC::GCS::ControladorPermisos::Instance()->CargarXMLPermisos(xml, false);
+						break;
+					}
 				}
-				config->SetPath(wxT(".."));
-				bCont = config->GetNextGroup(str, dummy);
 			}
 		}
 		catch(GNC::GCS::ControladorPermisosException& ex) {
@@ -655,7 +633,7 @@ int Ginkgo::OnExit()
 	GIL::XMLRPC::XMLRPCController::FreeInstance();
 	GNC::GCS::ControladorAcciones::FreeInstance();
 	GNC::GCS::ControladorComandos::FreeInstance();
-	GIL::DICOM::ControladorImportacionPACS::FreeInstance();
+	GIL::DICOM::PACSController::FreeInstance();
 	GNC::ControladorExtensiones::FreeInstance();
 	GNC::GCS::ControladorEventos::FreeInstance();
 	GNC::GCS::ControladorCarga::FreeInstance();
@@ -679,6 +657,7 @@ int Ginkgo::OnExit()
 		delete m_pServer;
 	}
 #endif
+	GNC::GCS::ConfigurationController::FreeInstance();
 
 	return wxApp::OnExit();
 }
@@ -705,9 +684,6 @@ void Ginkgo::DoProgress(wxString str)
 	// Dibujado del texto
 	wdc.SetTextForeground(colorTexto);
 	wdc.DrawText(str, 190, srcDC.GetSize().y - 37);
-
-	// Permitir procesado de eventos pendientes
-	wxYield();
 }
 
 void Ginkgo::WriteHeaderLog(){
@@ -729,32 +705,4 @@ void Ginkgo::WriteHeaderLog(){
 
 	LOG_INFO("Core", "Arrancando Ginkgo " + version.str() + "    " + std::string(date.ToUTF8()));
 }
-
-void Ginkgo::SetConfig()
-{
-#ifdef _WINDOWS
-	wxString pathEjecutable = wxStandardPaths::Get().GetExecutablePath();
-	wxFileName fileName(pathEjecutable);
-	fileName.SetExt(wxT("ini"));
-	wxString pathIni = fileName.GetLongPath();
-	if(wxFileExists(pathIni)) {
-		wxFileConfig* fileConfig = new wxFileConfig(wxEmptyString,wxEmptyString,pathIni,wxEmptyString,wxCONFIG_USE_LOCAL_FILE);
-		wxConfigBase::Set(fileConfig);
-		wxConfigBase::DontCreateOnDemand();
-	} else {
-		//se inicializa el fichero de propiedades
-		wxConfigBase *config = new wxFileConfig(wxT("Ginkgo"), wxT("Metaemotion"),wxEmptyString,wxEmptyString,wxCONFIG_USE_LOCAL_FILE );
-		wxConfigBase::Set(config);
-		wxConfigBase::DontCreateOnDemand();
-	}
-#else
-	//se inicializa el fichero de propiedades
-	wxConfigBase *config = new wxFileConfig(wxT("Ginkgo"), wxT("Metaemotion"),wxEmptyString,wxEmptyString,wxCONFIG_USE_LOCAL_FILE );
-	wxConfigBase::Set(config);
-	wxConfigBase::DontCreateOnDemand();
-#endif
-
-}
-
-
 //endregion
