@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: comandomergediagnosticwithimage.cpp 3648 2011-04-04 11:56:18Z tovar $
+*  $Id: comandomergediagnosticwithimage.cpp 3995 2011-07-13 18:24:42Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -10,31 +10,30 @@
 *  See License.txt for details
 *
 */
-
-
-#include <api/globals.h>
-#include <api/ientorno.h>
-
-#include <api/internacionalizacion.h>
 #include <sstream>
 
 #include <wx/filename.h>
 #include <wx/file.h>
 #include <wx/dir.h>
 #include <wx/xml/xml.h>
-#include <wx/confbase.h>
+#include <main/controllers/configurationcontroller.h>
+#include <wx/mstream.h>
+#include <wx/sstream.h>
+
+#include <api/globals.h>
+#include <api/ientorno.h>
 #include <api/icontextoestudio.h>
+#include <api/dicom/idicommanager.h>
+
 #include <main/entorno.h>
 #include <main/controllers/controladoreventos.h>
 #include <main/controllers/controladorhistorial.h>
 #include <main/controllers/controladorextensiones.h>
-#include <api/idicommanager.h>
-#include <eventos/eventosginkgo.h>
-#include <wx/mstream.h>
-#include <wx/sstream.h>
 
-#include "comandomergediagnosticwithimage.h"
-#include "comandopacs.h"
+#include <eventos/eventosginkgo.h>
+
+#include <commands/comandomergediagnosticwithimage.h>
+#include <commands/comandopacs.h>
 
 #define IDC_MERGE_DIAGNOSTIC           114
 
@@ -63,23 +62,25 @@ namespace GADAPI {
 		//search module and tags replace...
 		std::string uidImportater = GNC::GCS::ControladorHistorial::Instance()->GetUIDImporterFromDiagnosticStudy(m_uidDiagnosticStudy);
 		GNC::ControladorExtensiones::ListaModulos listaModulos = GNC::ControladorExtensiones::Instance()->Modulos();
-		for(GNC::ControladorExtensiones::IteradorListaModulos itModulos = listaModulos.begin(); itModulos!= listaModulos.end(); ++itModulos){
-			std::ostringstream os;
-			os<<itModulos->second->GetUID();
-			if(os.str() == uidImportater){
-				//get all files of series included in this diagnostic
-				std::list<std::string> pathsOriginal;
-				GNC::GCS::ControladorHistorial::Instance()->GetReferencedFiles(m_uidDiagnosticStudy, pathsOriginal);
-				for (std::list<std::string>::iterator it = pathsOriginal.begin(); it != pathsOriginal.end(); ++it)
-				{
-					T_File file;
-					file.m_path = (*it);
-					m_oldImages.push_back(file);
+		bool salir = false;
+		for(GNC::ControladorExtensiones::IteradorListaModulos itModulos = listaModulos.begin(); itModulos!= listaModulos.end() && !salir; ++itModulos){
+			for (GNC::GCS::IControladorModulo::IteradorListaModos itModos = (*itModulos).second->GetListaModos().begin(); itModos != (*itModulos).second->GetListaModos().end(); ++itModos) {
+				if ((*itModos)->SupportsImportationUID(uidImportater)) {
+					//get all files of series included in this diagnostic
+					std::list<std::string> pathsOriginal;
+					GNC::GCS::ControladorHistorial::Instance()->GetReferencedFiles(m_uidDiagnosticStudy, pathsOriginal);
+					for (std::list<std::string>::iterator it = pathsOriginal.begin(); it != pathsOriginal.end(); ++it)
+					{
+						T_File file;
+						file.m_path = (*it);
+						m_oldImages.push_back(file);
+					}
+					
+					(*itModulos).second->GetTagsPrivadosReplace(m_mapTagsPrivadosReplace);
+					m_diagnosticMode = (*itModulos).second->GetDiagnosticMode();
+					salir = true;
+					break;
 				}
-
-				(*itModulos).second->GetTagsPrivadosReplace(m_mapTagsPrivadosReplace);
-				m_diagnosticMode = (*itModulos).second->GetDiagnosticMode();
-				break;
 			}
 		}
 		do {
@@ -145,7 +146,7 @@ namespace GADAPI {
 
 		//first of all create new sop instance uids and fill in dictionaries
 		{
-			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
 			GNC::GCS::IControladorHistorial::ModeloDCM fileModel;
 			for (ComandoMergeDiagnosticWithImageParams::TFileList::iterator it = m_pMergeParams->m_oldImages.begin(); it !=  m_pMergeParams->m_oldImages.end(); ++it)
 			{
@@ -168,7 +169,7 @@ namespace GADAPI {
 				}
 				m_pMergeParams->m_newImages.push_back(newFile);
 			}
-			GNC::Entorno::Instance()->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDicomManager);
+			GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pDicomManager);
 		}
 
 		if (!NotificarProgreso(0.1, _Std("Merging files...")) )
@@ -207,9 +208,9 @@ namespace GADAPI {
 	{
 		std::string uidEstudio;
 		{
-			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
 			uidEstudio = pDicomManager->GetNewUID();
-			GNC::Entorno::Instance()->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDicomManager);
+			GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pDicomManager);
 		}
 
 		std::string pathDiagnostic("");
@@ -219,10 +220,10 @@ namespace GADAPI {
 		ComandoMergeDiagnosticWithImageParams::TFileList::iterator itNew = m_pMergeParams->m_newImages.begin();
 		for (ComandoMergeDiagnosticWithImageParams::TFileList::iterator itOld = m_pMergeParams->m_oldImages.begin(); itOld !=  m_pMergeParams->m_oldImages.end(); ++itOld, ++itNew, i++)
 		{
-			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
 			if (!NotificarProgreso(0.8f * ((float)i/m_pMergeParams->m_oldImages.size()), std::string(wxString::Format(_("Merging file %d of %d"),i, m_pMergeParams->m_oldImages.size()).ToUTF8())) )
 			{
-				GNC::Entorno::Instance()->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDicomManager);
+				GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pDicomManager);
 				return false;
 			}
 
@@ -267,7 +268,7 @@ namespace GADAPI {
 			wxString pathNewImage = GetFichero(m_pMergeParams->m_tempPath, wxT("dcm"));
 			pDicomManager->AlmacenarFichero(std::string(TOPATH(pathNewImage)));
 			(*itNew).m_path = TOPATH(pathNewImage);
-			GNC::Entorno::Instance()->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDicomManager);
+			GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pDicomManager);
 		}
 
 		return true;
@@ -277,19 +278,19 @@ namespace GADAPI {
 	{
 		std::string uidEstudio;
 		{
-			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
 			uidEstudio = pDicomManager->GetNewUID();
-			GNC::Entorno::Instance()->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDicomManager);
+			GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pDicomManager);
 		}
 
 		int i = 0;
 		ComandoMergeDiagnosticWithImageParams::TFileList::iterator itNew = m_pMergeParams->m_newImages.begin();
 		for (ComandoMergeDiagnosticWithImageParams::TFileList::iterator itOld = m_pMergeParams->m_oldImages.begin(); itOld !=  m_pMergeParams->m_oldImages.end(); ++itOld, ++itNew, ++i)
 		{
-			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+			GIL::DICOM::IDICOMManager* pDicomManager = GNC::Entorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
 			if (!NotificarProgreso(0.8f * ((float)i/m_pMergeParams->m_oldImages.size()), std::string(wxString::Format(_("Merging file %d of %d"),i, m_pMergeParams->m_oldImages.size()).ToUTF8())) )
 			{
-				GNC::Entorno::Instance()->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDicomManager);
+				GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pDicomManager);
 				return false;
 			}
 
@@ -332,7 +333,7 @@ namespace GADAPI {
 			wxString pathNewImage = GetFichero(m_pMergeParams->m_tempPath, wxT("dcm"));
 			pDicomManager->AlmacenarFichero(std::string(TOPATH(pathNewImage)));
 			(*itNew).m_path = TOPATH(pathNewImage);
-			GNC::Entorno::Instance()->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDicomManager);
+			GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pDicomManager);
 		}
 
 		return true;
@@ -349,7 +350,7 @@ namespace GADAPI {
 		//tags erased
 		{
 			std::string tagsRemove[13] = {"0008|0005","0008|0060","0008|0016", "0008|0032","0008|0033","0040|a040","0020|0010","0020|0011","0020|0012","0020|0013","0040|a050","0040|a491","0040|a493"};
-			GIL::DICOM::TipoJerarquia::ListaTags::iterator it;
+			GIL::DICOM::ListaTags::iterator it;
 			for (int i = 0; i< 13; ++i) {
 				it = data.tags.find(tagsRemove[i]);
 				if (it != data.tags.end()) {
