@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: comandopacs.cpp 3700 2011-04-15 07:34:44Z tovar $
+*  $Id: comandopacs.cpp 3830 2011-05-06 13:30:18Z carlos $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -22,7 +22,7 @@
 #include <api/globals.h>
 #include <api/inotificadoresherramientas.h>
 #include <api/icontroladoreventos.h>
-#include <api/internacionalizacion.h>
+
 #include <api/icontextoestudio.h>
 
 #include <eventos/eventosginkgo.h>
@@ -32,7 +32,7 @@
 #include <main/controllers/controladoreventos.h>
 #include <main/controllers/controladorcomandos.h>
 #include <main/controllers/controladorpermisos.h>
-#include <main/controllers/controladorimportacionpacs.h>
+#include <main/controllers/pacscontroller.h>
 #include <main/controllers/controladorlog.h>
 #include <main/controllers/dcmtk/dicomservers.h>
 #include <main/controllers/controladorvistas.h>
@@ -173,7 +173,7 @@ namespace GADAPI
 								const IModeloSerie& s = *it3;
 								for (IModeloSerie::ListaImagenesType::const_iterator it4 = s.ListaImagenes().begin(); it4 != s.ListaImagenes().end(); it4++) {
 									const IModeloImagen& im = *it4;
-									if(GIL::DICOM::ControladorImportacionPACS::Instance()->GetRutaImagenTemp(p.GetUID(),e.GetUID(),s.GetUID(),im.GetUID(), rutaImagen)){
+									if(GIL::DICOM::PACSController::Instance()->GetRutaImagenTemp(p.GetUID(),e.GetUID(),s.GetUID(),im.GetUID(), rutaImagen)){
 										rutas.push_back(rutaImagen);
 									}
 								}
@@ -208,10 +208,10 @@ namespace GADAPI
 		if (!NotificarProgreso(0.0f,tarea)) {
 		    return;
 		}
-		GIL::DICOM::IControladorImportacionPACS* pCI = NULL;
+		GIL::DICOM::IPACSController* pCI = NULL;
 		try {
 
-			pCI = GNC::Entorno::Instance()->GetControladorImportacionPACS();
+			pCI = GNC::Entorno::Instance()->GetPACSController();
 
 			pCI->GetConnection(this);
 
@@ -273,7 +273,7 @@ namespace GADAPI
 								m_pPACSParams->m_pModelo,this
 							);
 						}
-						GNC::Entorno::Instance()->GetControladorImportacionPACS()->BuscarSeries(
+						GNC::Entorno::Instance()->GetPACSController()->BuscarSeries(
 							this,
 							m_pPACSParams->m_serverSeleccionado, // Server ID
 							m_pPACSParams->m_studyUID,
@@ -323,10 +323,10 @@ namespace GADAPI
 		}
 
 		std::string cadenaVacia;
-		GIL::DICOM::IControladorImportacionPACS* pCI = NULL;
+		GIL::DICOM::IPACSController* pCI = NULL;
 
 		try {
-			pCI = GNC::Entorno::Instance()->GetControladorImportacionPACS();
+			pCI = GNC::Entorno::Instance()->GetPACSController();
 			pCI->GetConnection(this);
 			switch (m_pPACSParams->m_Ambito) {
 				case ComandoPACSParams::TA_Estudio:
@@ -415,9 +415,9 @@ namespace GADAPI
 		if (!NotificarProgreso(0.0f,tarea)) {
 		    return;
 		}
-		GIL::DICOM::IControladorImportacionPACS* pCI = NULL;
+		GIL::DICOM::IPACSController* pCI = NULL;
 		try {
-			pCI = GNC::Entorno::Instance()->GetControladorImportacionPACS();
+			pCI = GNC::Entorno::Instance()->GetPACSController();
 			pCI->GetConnection(this);
 			#ifdef _GINKGO_DEBUG
 			//try {
