@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: tagsprivadoscomunes.h 3696 2011-04-14 08:40:28Z carlos $
+*  $Id: tagsprivadoscomunes.h 3963 2011-07-11 14:03:51Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,8 +14,8 @@
 //tags privados comunes a todos los diagnosticos
 #define UID_TAGS_PRIVADOS_COMUNES "METAEMOTION GINKGO"
 
-#define TAG_WIDGETS					    0xb;
-#define TAG_XML_INTEGRACION		    0xa;
+#define TAG_WIDGETS					    0xb
+#define TAG_XML_INTEGRACION		    0xa
 
 //en estos tags va la info relacionada con los informes en general
 #define UID_TAGS_PRIVADOS_INFORME "METAEMOTION GINKGO DIAGNOSTIC"
