@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: controladorcarga.cpp 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: controladorcarga.cpp 3834 2011-05-10 07:42:57Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,7 +14,7 @@
 //#define _GINKGO_TRACE
 #include <api/globals.h>
 #include <api/icomando.h>
-#include <api/idicommanager.h>
+#include <api/dicom/idicommanager.h>
 #include <api/icontroladorcomandos.h>
 #include <api/imodelointegracion.h>
 #include <api/icontextoestudio.h>
@@ -24,12 +24,12 @@
 #include "controladorcarga.h"
 #include "controladoreventos.h"
 #include "controladorvistas.h"
-#include "controladorimportacionpacs.h"
+#include "pacscontroller.h"
 
 #include <wx/filename.h>
 #include <wx/file.h>
 #include <wx/thread.h>
-#include <api/internacionalizacion.h>
+
 
 #ifdef __DEPRECATED
 #undef __DEPRECATED
@@ -145,9 +145,9 @@ vtkSmartPointer<vtkImageData> GNC::GCS::ControladorCarga::CargarITKMultidimensio
 {
 	//primero leemos el pixeltype...
 	GIL::DICOM::TipoJerarquia base;
-	GIL::DICOM::IDICOMManager* pDicomManager = GIL::DICOM::ControladorImportacionPACS::Instance()->CrearInstanciaDeDICOMManager();
+	GIL::DICOM::IDICOMManager* pDicomManager = GIL::DICOM::PACSController::Instance()->CrearInstanciaDeDICOMManager();
 	pDicomManager->CargarFichero(listaFicheros[0],base);
-	GIL::DICOM::ControladorImportacionPACS::Instance()->LiberarInstanciaDeDICOMManager(pDicomManager);
+	GIL::DICOM::PACSController::Instance()->LiberarInstanciaDeDICOMManager(pDicomManager);
 	std::string tag;
 
 	if(base.getTag(std::string("0028|0002"),tag)){
