@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorcomandos.cpp 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: controladorcomandos.cpp 3849 2011-05-16 13:26:20Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,6 +14,7 @@
 //#define _GINKGO_TRACE
 
 #include <api/globals.h>
+#include <api/threads/thread.h>
 #include <api/icomando.h>
 
 #include <main/controllers/controladorlog.h>
@@ -29,63 +30,7 @@
 //#undef GTRACE
 //#define GTRACE(expr) std::cout << expr << std::endl
 
-#if defined (_WINDOWS)
-#define MS_VC_EXCEPTION 0x406D1388
 
-#pragma pack(push,8)
-typedef struct tagTHREADNAME_INFO
-{
-   DWORD dwType; // Must be 0x1000.
-   LPCSTR szName; // Pointer to name (in user addr space).
-   DWORD dwThreadID; // Thread ID (-1=caller thread).
-   DWORD dwFlags; // Reserved for future use, must be zero.
-} THREADNAME_INFO;
-#pragma pack(pop)
-
-void GNC::GCS::Threading::SetThreadName( long threadID, const std::string& threadName)
-{
-   //Sleep(10);
-   THREADNAME_INFO info;
-   info.dwType = 0x1000;
-   info.szName = threadName.c_str();
-   info.dwThreadID = threadID;
-   info.dwFlags = 0;
-
-   __try
-   {
-      RaiseException( MS_VC_EXCEPTION, 0, sizeof(info)/sizeof(ULONG_PTR), (ULONG_PTR*)&info );
-   }
-   __except(EXCEPTION_EXECUTE_HANDLER)
-   {
-   }
-}
-#elif defined(__WXOSX__)
-#include <pthread.h>
-#include <sys/signal.h>
-
-void GNC::GCS::Threading::SetThreadName( long /*threadID*/, const std::string& threadName)
-{
-	//pthread_setname_np(threadName.c_str());
-}
-
-void FooSignalHandler(int sig)
-{
-	GTRACE("SIGUSR1 recibido");
-}
-#else
-#include <pthread.h>
-#include <sys/signal.h>
-
-void GNC::GCS::Threading::SetThreadName( long threadID, const std::string& threadName)
-{
-}
-
-void FooSignalHandler(int sig)
-{
-	GTRACE("SIGUSR1 recibido");
-}
-
-#endif
 GNC::LanzadorComandos::LanzadorComandos(GNC::GCS::IComando* pComando)
 {
 	//std::cout << "LanzadorComandos::LanzadorComandos()" << this << std::endl;
