@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: controladorhl7.cpp 3681 2011-04-12 10:53:31Z tovar $
+ *  $Id: controladorhl7.cpp 3963 2011-07-11 14:03:51Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -26,9 +26,8 @@
 #include <signal.h>
 #endif
 #include <wx/tokenzr.h>
-#include <wx/config.h>
 #include <wx/filename.h>
-#include <api/internacionalizacion.h>
+
 
 #include "controladorhl7.h"
 #include "parserxmlspanish.h"
@@ -41,6 +40,7 @@
 #include <api/iguiasmensajeriasacyl.h>
 #include <api/aetwildcards.h>
 #include <main/controllers/controladorextensiones.h>
+#include <main/controllers/configurationcontroller.h>
 #include <main/controllers/controladorlog.h>
 #include <main/entorno.h>
 #include "dcmtk/dicomservers.h"
@@ -49,9 +49,15 @@
 GIL::HL7::ControladorHL7::ControladorHL7(TipoInterpretacion interpretacion, TipoProtocolo protocolo) : GIL::HL7::IControladorHL7(interpretacion, protocolo)
 {
 	GnkPtr<GIL::HL7::IXMLIntegrationParser> spanish(new GIL::HL7::ParserXMLSpanish());
-	RegisterParser(spanish->GetKey(), spanish);
+	std::list<std::string> keys = spanish->GetKeys();
+	for (std::list<std::string>::iterator it = keys.begin(); it != keys.end(); ++it) {
+		RegisterParser((*it), spanish);
+	}
 	GnkPtr<GIL::HL7::IXMLIntegrationParser> english(new GIL::HL7::ParserXMLEnglish());
-	RegisterParser(english->GetKey(), english);
+	keys = english->GetKeys();
+	for (std::list<std::string>::iterator it = keys.begin(); it != keys.end(); ++it) {
+		RegisterParser((*it), spanish);
+	}
 }
 
 GIL::HL7::ControladorHL7::~ControladorHL7()
@@ -107,8 +113,7 @@ void GIL::HL7::ControladorHL7::ParsearModeloIntegracion(GNC::GCS::IEntorno::List
 
 std::string GIL::HL7::ControladorHL7::GetUID(const std::string& idPlantilla) const
 {
-	wxConfigBase* config = wxConfigBase::Get();
-	wxString uid;
+	std::string uid;
 	wxString plantillawx(idPlantilla.c_str(), wxConvUTF8);
 
 	wxStringTokenizer tkid(plantillawx,wxString::FromUTF8("^"));
@@ -124,24 +129,22 @@ std::string GIL::HL7::ControladorHL7::GetUID(const std::string& idPlantilla) con
 	std::string descripcion(tkid.GetNextToken().ToUTF8());
 	std::string namespaceid(tkid.GetNextToken().ToUTF8());
 
-	config->SetPath(wxString::FromUTF8("/GinkgoCore/HCE/Plantillas"));
-
 	GNC::ControladorExtensiones* pCE = GNC::ControladorExtensiones::Instance();
 
 	for (GNC::ControladorExtensiones::IteradorConstanteListaModulos it = pCE->Modulos().begin(); it != pCE->Modulos().end(); it++) {
 		const GNC::GCS::IControladorModulo* m = (*it).second;
 
-		LOG_TRACE("HL7", "Parsing module: " << m->GetSID().c_str() << ", " << m->GetUID().c_str() );
+		LOG_TRACE("HL7", "Parsing module: " << ", " << m->GetUID().c_str() );
 
-		std::string entradaConf = "TUID" + m->GetSID();
+		std::string entradaConf = "TUID" + m->GetUID();
 
-		LOG_TRACE("HL7", "EntradaConf = TUID" << m->GetSID().c_str() ); 
+		LOG_TRACE("HL7", "EntradaConf = TUID" << m->GetUID().c_str() ); 
 
-		config->Read(wxString::FromUTF8(entradaConf.c_str()), &uid, wxEmptyString);
+		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE/Plantillas", entradaConf, uid);
 
-		LOG_TRACE("HL7", "tuid = " << uid.ToUTF8()); 
+		LOG_TRACE("HL7", "tuid = " << uid); 
 
-		wxStringTokenizer tkz(uid, wxT(";"));
+		wxStringTokenizer tkz(wxString::FromUTF8(uid.c_str()), wxT(";"));
 
 		while (tkz.HasMoreTokens()){
 			wxString token = tkz.GetNextToken();
@@ -149,7 +152,7 @@ std::string GIL::HL7::ControladorHL7::GetUID(const std::string& idPlantilla) con
 			numTokens = tkidmodulo.CountTokens();
 			if (numTokens != 3){
 				std::ostringstream os;
-				os << _Std("Id malformed template in the module configuration") << m->GetNombre() << "(" << (std::string(uid.ToUTF8())).c_str() << _Std("):\nIs not a valid HL7 identifier (ie: code^description^namespaceId)");
+				os << _Std("Id malformed template in the module configuration") << m->GetNombre() << "(" << uid.c_str() << _Std("):\nIs not a valid HL7 identifier (ie: code^description^namespaceId)");
 				throw HL7Exception(os.str(),"PID");
 			}
 
@@ -186,7 +189,7 @@ std::string GIL::HL7::ControladorHL7::GetNombreModulo(const std::string& idPlant
 	return nombreModulo;
 }
 
-std::string GIL::HL7::ControladorHL7::GetSIDModulo(const std::string& idPlantilla) const
+std::string GIL::HL7::ControladorHL7::GetUIDModulo(const std::string& idPlantilla) const
 {
 	std::string uidModulo = GetUID(idPlantilla);
 	std::string sidModulo("");
@@ -196,7 +199,7 @@ std::string GIL::HL7::ControladorHL7::GetSIDModulo(const std::string& idPlantill
 		std::ostringstream os;
 		os << itModulos->first;
 		if(os.str() == uidModulo) {
-			return itModulos->second->GetSID();
+			return itModulos->second->GetUID();
 		}
 	}
 	return sidModulo;
@@ -220,8 +223,6 @@ void GIL::HL7::ControladorHL7::ConstruirMensajeDeEvidencias(GIL::HL7::Message& m
 
 		time_t         timestamp = std::time(NULL);
 
-		wxString       valor;
-
 		std::string    idOrganizacionReceptora;
 		std::string    idSistemaPeticionario;
 		std::string    idAplicacionRellenadora;
@@ -233,18 +234,10 @@ void GIL::HL7::ControladorHL7::ConstruirMensajeDeEvidencias(GIL::HL7::Message& m
 		std::string    processingId;
 		std::string    fillerId;
 
-		wxConfigBase* config = wxConfigBase::Get();
-		config->SetPath(wxT("/GinkgoCore/HCE"));
-
-		config->Read(wxT("IDOrganizacionReceptora"), &valor, wxEmptyString);
-		idOrganizacionReceptora = valor.ToUTF8();
-
-		config->Read(wxT("IDSistemaPeticionario"), &valor, wxEmptyString);
-		idSistemaPeticionario = valor.ToUTF8();
-
-		config->Read(wxT("IDAplicacionRellenadora"), &valor, wxEmptyString);
-		idAplicacionRellenadora = valor.ToUTF8();
-
+		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","IDOrganizacionReceptora",idOrganizacionReceptora);
+		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","IDSistemaPeticionario",idSistemaPeticionario);
+		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","IDAplicacionRellenadora",idAplicacionRellenadora);
+		
 		if (modelo->PACSAlmacenamiento.size() > 0) {
 			idAplicacionPACS = modelo->PACSAlmacenamiento;			
 		}
@@ -257,31 +250,22 @@ void GIL::HL7::ControladorHL7::ConstruirMensajeDeEvidencias(GIL::HL7::Message& m
 			}
 		}
 
-		config->SetPath(wxT("/GinkgoCore/Estacion"));
-
-		config->Read(wxT("CentroNombre"),&valor,wxEmptyString);
-		nombreCentroLocal = valor.ToUTF8();
-
-		config->Read(wxT("CentroId"),&valor,wxEmptyString);
-		idCentroLocal = valor.ToUTF8();
-
+		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",nombreCentroLocal);
+		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroId",idCentroLocal);
+		
 		{
 			std::stringstream ss;
 
-			std::string sidModulo = GetSIDModulo(modelo->idPlantilla);
-			ss << "GNK_" << sidModulo << "." << timestamp;
+			std::string uidModulo = GetUIDModulo(modelo->idPlantilla);
+			ss << "GNK_" << uidModulo << "." << timestamp;
 
 			processingId = ss.str();
 		}
 
 		{
-			std::stringstream ss;
-
-			config->SetPath(wxT("/GinkgoCore/PACS/Local"));
-
-			config->Read(wxT("AET"),&valor,wxEmptyString);
-			std::string aetLocal( GNC::GCS::AETWildcards::Parse(std::string(valor.ToUTF8())) );
+			std::string aetLocal = GNC::Entorno::Instance()->GetDicomLocalAET();
 
+			std::ostringstream ss;
 			ss << timestamp << "." << aetLocal;
 
 			fillerId = ss.str();
@@ -289,9 +273,9 @@ void GIL::HL7::ControladorHL7::ConstruirMensajeDeEvidencias(GIL::HL7::Message& m
 
 		GIL::Sacyl::Messages::ORU_R01Interpreter oi;
 
-			config->SetPath(wxT("/GinkgoCore/HCE"));
-			config->Read(wxT("IDGinkgoApplication"),&valor,wxT("GINKGO"));
-			oi.SetSendingApplication(std::string(valor.ToUTF8()));
+			std::string value;
+			GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","IDGinkgoApplication",value, "GINKGO");
+			oi.SetSendingApplication(value);
 			oi.SetSendingFacility(modelo->Medico.idCentro);
 
 			oi.SetReceivingApplication(modelo->HCE.Sid);
@@ -500,22 +484,18 @@ void GIL::HL7::ControladorHL7::ConstruirMensajeDeEvidencias(GIL::HL7::Message& m
 /* Envia el mensaje por MLLP */
 void GIL::HL7::ControladorHL7::EnviarMensaje(const GIL::HL7::Message& msg, bool procesarACK) const
 {
-	wxString hostname;
-	wxString puerto;
+	std::string hostname, port;
 
-	wxConfigBase* config = wxConfigBase::Get();
-	config->SetPath(wxT("/GinkgoCore/HCE"));
+	GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","HostnameMI",hostname);
+	GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/HCE","PuertoMI",port);
+	std::ostringstream ostr;
+	ostr << hostname << ":" << port;
+	std::string url = ostr.str();
 
-	config->Read(wxT("HostnameMI"), &hostname, wxEmptyString);
-
-	config->Read(wxT("PuertoMI"), &puerto, wxEmptyString);
-
-	std::string url( (hostname + wxT(":") + puerto).ToUTF8());
-
-	if (hostname.empty()) {
+	if (hostname.size() == 0) {
 		throw HL7Exception(_Std("Integration engine hostname not set"), "NET");
 	}
-	if (puerto.empty()) {
+	if (port.size() == 0) {
 		throw HL7Exception(_Std("Integration engine port not set"), "NET");
 	}
 
