@@ -13,13 +13,14 @@
 #define LOGGER "C-GET"
 #include <api/icontroladorlog.h>
 #include <main/controllers/controladorlog.h>
-#include <api/imodelodicom.h>
+#include <api/dicom/imodelodicom.h>
 #include <main/controllers/controladorpermisos.h>
-#include <api/icontroladorimportacionpacs.h>
-#include <api/internacionalizacion.h>
+#include <api/controllers/ipacscontroller.h>
+
 #include <api/icontextoestudio.h>
 
 #include "istorecallback.h"
+#include <wx/intl.h>
 
 #include "dicomnetwork.h"
 #include "dicomgetassociation.h"
@@ -63,7 +64,7 @@ CONDITION GetAssociation::SendObject(DcmDataset *dataset) {
 	return getSCU(dataset);
 }
 
-void GetAssociation::SetStorageSOPClasses(const SOPClassList& SOPClasses)
+void GetAssociation::SetStorageSOPClasses(const GIL::DICOM::SOPClassList& SOPClasses)
 {
 	this->SOPClasses = SOPClasses;
 }
@@ -72,7 +73,7 @@ void GetAssociation::OnAddPresentationContext(T_ASC_Parameters * params) {
 
 	unsigned int pid = 1;
 
-	CONDITION cond = ASC_addPresentationContext(params, pid, m_abstractSyntax, AllTransferSyntaxes, 3);
+	CONDITION cond = ASC_addPresentationContext(params, pid, m_abstractSyntax.c_str(), AllTransferSyntaxes, 3);
 	if (cond.bad()) {
 		LOG_ERROR(ambitolog, "Unable to add GETStudyRootQueryRetrieveInformationModel presentation context");
 		return;
@@ -81,7 +82,7 @@ void GetAssociation::OnAddPresentationContext(T_ASC_Parameters * params) {
 	pid += 2;
 
 	if (SOPClasses.size() > 0) {
-		for (unsigned int i = 0; pid <= 255 && i < (unsigned int) numberOfDcmLongSCUStorageSOPClassUIDs && cond.good(); ++i) {
+		/*for (unsigned int i = 0; pid <= 255 && i < (unsigned int) numberOfDcmLongSCUStorageSOPClassUIDs && cond.good(); ++i) {
 			if ( SOPClasses.find(dcmLongSCUStorageSOPClassUIDs[i]) != SOPClasses.end() ) {
 
 				for (unsigned int j = 0; pid <= 255 && j < AllTransferSyntaxesCount && cond.good(); j++) {
@@ -89,6 +90,16 @@ void GetAssociation::OnAddPresentationContext(T_ASC_Parameters * params) {
 					pid += 2;
 				}
 			}
+		}*/
+		const GIL::DICOM::TransferSyntaxMap& tsMap = GIL::DICOM::Conformance::GetTransferSyntaxes();
+		
+		for (GIL::DICOM::SOPClassList::const_iterator itSopClass = SOPClasses.begin(); pid <= 255 && itSopClass != SOPClasses.end() && cond.good(); ++itSopClass) {
+			for (GIL::DICOM::TransferSyntaxMap::const_iterator itTS = tsMap.begin(); pid <= 255 && itTS != tsMap.end() && cond.good(); itTS++) {
+				const char* ts[] = {(*itTS).second.c_str()};
+				cond = ASC_addPresentationContext(params, pid, (*itSopClass).c_str(), ts, 1);
+				pid += 2;
+			}
+
 		}
 
 		if (pid >= 255) {
@@ -96,8 +107,8 @@ void GetAssociation::OnAddPresentationContext(T_ASC_Parameters * params) {
 		}
 	}
 	else {
-		for (unsigned int i = 0; pid <= 255 && i < (unsigned int) numberOfDcmLongSCUStorageSOPClassUIDs && cond.good(); ++i) {
-			cond = ASC_addPresentationContext(params, pid, dcmLongSCUStorageSOPClassUIDs[i], AllTransferSyntaxes, AllTransferSyntaxesCount);
+		for (unsigned int i = 0; pid <= 255 && i < (unsigned int) numberOfDcmShortSCUStorageSOPClassUIDs && cond.good(); ++i) {
+			cond = ASC_addPresentationContext(params, pid, dcmShortSCUStorageSOPClassUIDs[i], AllTransferSyntaxes, AllTransferSyntaxesCount);
 			pid += 2;			
 		}
 		if (pid >= 255) {
@@ -326,7 +337,7 @@ CONDITION GetAssociation::getSCU(DcmDataset *pdset) {
 	}
 
 	//sopClass = m_abstractSyntaxMove;
-	sopClass = m_abstractSyntax;
+	sopClass = m_abstractSyntax.c_str();
 
 	// which presentation context should be used
 	presId = ASC_findAcceptedPresentationContextID(assoc, sopClass);
@@ -383,7 +394,7 @@ CONDITION GetAssociation::getSCU(DcmDataset *pdset) {
 
 	if(m_errorMessage != "")
 	{
-		throw GIL::DICOM::PACSException(m_errorMessage, "Adquisition");
+		throw GIL::DICOM::PACSException(m_errorMessage, "Acquisition");
 	}
 
 	return cond;
@@ -408,7 +419,7 @@ void GetAssociation::subOpCallback(void *pCaller, T_ASC_Network *aNet, T_ASC_Ass
 
 	if (*subAssoc == NULL) {
 		// negotiate association
-		LOG_DEBUG(caller->ambitolog, "Aceptando subAsociacin");
+		LOG_DEBUG(caller->ambitolog, "Aceptando subAsociacin");
 		caller->acceptSubAssoc(aNet, subAssoc);
 	}
 	else {
@@ -452,7 +463,7 @@ CONDITION GetAssociation::subOpSCP(T_ASC_Association **subAssoc) {
 				cond = echoSCP(*subAssoc, &msg, presID);
 				break;
 			default:
-				LOG_ERROR(ambitolog, "Tipo de comando incorrecto. Slo se aceptan C-STORE_RQ o C-ECHO_RQ en esta etapa" << cond.text());
+				LOG_ERROR(ambitolog, "Tipo de comando incorrecto. Sólo se aceptan C-STORE_RQ o C-ECHO_RQ en esta etapa" << cond.text());
 				cond = DIMSE_BADCOMMANDTYPE;
 				break;
 		}
@@ -466,10 +477,10 @@ CONDITION GetAssociation::subOpSCP(T_ASC_Association **subAssoc) {
 		return cond;
 	}
 	else if (cond == DUL_PEERABORTEDASSOCIATION) {
-		LOG_ERROR(ambitolog, "El PACS remoto abort la asociacin"  << cond.text());
+		LOG_ERROR(ambitolog, "El PACS remoto abort la asociacin"  << cond.text());
 	}
 	else if (cond != EC_Normal) {
-		LOG_ERROR(ambitolog, "Ha ocurrido un error y se abortar la asociacin"  << cond.text());
+		LOG_ERROR(ambitolog, "Ha ocurrido un error y se abortar la asociacin"  << cond.text());
 		// some kind of error so abort the association
 		cond = ASC_abortAssociation(*subAssoc);
 	}
@@ -542,7 +553,7 @@ void GetAssociation::storeSCPCallback(void *callbackData, T_DIMSE_StoreProgress
 		GNC::GCS::Permisos::EstadoPermiso estado = GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits", "study_size");
 		if (estado) {
 			if (estado.ObtenerValor<long>() < (caller->m_bytesDescargados / 1024) ) {
-				caller->m_errorMessage = _Std("Study download size limit exceded");
+				caller->m_errorMessage = _Std("Study download size limit exceeded");
 				rsp->DimseStatus = STATUS_STORE_Refused_OutOfResources;
 				caller->Stop();
 				ASC_releaseAssociation(caller->assoc);
