@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dicomimg2dcm.cpp 3698 2011-04-14 12:38:49Z carlos $
+ *  $Id: dicomimg2dcm.cpp 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -37,7 +37,7 @@
 #include <dcmtk/dcmdata/dcfilefo.h>
 
 #include <main/controllers/controladorpermisos.h>
-#include <api/internacionalizacion.h>
+
 
 
 //en este grupo se almacenaran los atributos privados de ginkgo
@@ -159,14 +159,14 @@ namespace GIL {
 				}
 
 				unsigned char* imgData = img.GetData();
-				Inicializar(imgData, img.GetWidth(), img.GetHeight(), pICallback, debug, outputFormat);
+				TImageFile rgbLittleEndian(imgData, img.GetWidth(), img.GetHeight());
+				Inicializar(rgbLittleEndian, pICallback, debug, outputFormat);
 			} 
 		}
 
-		void DICOMImg2DCM::Inicializar(unsigned char* pixelData, const int ancho, const int alto, IInspectCallBack* pICallback, bool debug, TDICOMOutputFormat outputFormat)
+		void DICOMImg2DCM::Inicializar(TImageFile& fileDefinition, IInspectCallBack* pICallback, bool debug, TDICOMOutputFormat outputFormat)
 		{
-			I2DLittleEndianSource* littleEndianSource = new I2DLittleEndianSource();
-			littleEndianSource->setImageData(pixelData, ancho, alto, 3);
+			I2DLittleEndianSource* littleEndianSource = new I2DLittleEndianSource(fileDefinition);
 			Inicializar(littleEndianSource, pICallback, debug, outputFormat);
 		}
 
@@ -265,7 +265,8 @@ namespace GIL {
 					}
 
 					unsigned char* imgData = img.GetData();
-					Inicializar(imgData, img.GetWidth(), img.GetHeight(), pICallback, debug, outputFormat);
+					TImageFile rgbLittleEndian(imgData, img.GetWidth(), img.GetHeight());
+					Inicializar(rgbLittleEndian, pICallback, debug, outputFormat);
 				} else {
 					LiberarMemoria();
 					throw I2DException(cond.text());
@@ -375,7 +376,7 @@ namespace GIL {
 
 
 			// Insertamos todos los tags correspondientes a este nivel en la raiz (de haberla, si no: en el dataset).
-			for (TipoJerarquia::ListaTags::iterator it = base.tags.begin(); it != base.tags.end(); it++) {
+			for (ListaTags::iterator it = base.tags.begin(); it != base.tags.end(); it++) {
 				DcmElement* e = this->CrearElementoConValor((*it).first.c_str());
 				if (e != NULL) {
 					e->putString((*it).second.c_str());
