@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: dicommanager.cpp 3763 2011-04-25 12:07:55Z carlos $
+ *  $Id: dicommanager.cpp 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -647,7 +647,7 @@ namespace GIL
 			}
 
 			// Insertamos todos los tags correspondientes a este nivel en la raiz (de haberla, si no: en el dataset).
-			for (TipoJerarquia::ListaTags::iterator it = base.tags.begin(); it != base.tags.end(); it++) {
+			for (ListaTags::iterator it = base.tags.begin(); it != base.tags.end(); it++) {
 				DcmElement* e = this->CrearElementoConValor((*it).first.c_str());
 
 				if (e != NULL) {
