@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: dicommoveassocation.cpp 3609 2011-03-23 10:15:06Z carlos $
+ *  $Id: dicommoveassocation.cpp 3907 2011-07-01 07:27:36Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,11 +16,12 @@
 
 #include <api/icontroladorlog.h>
 #include <main/controllers/controladorlog.h>
-#include <api/imodelodicom.h>
+#include <api/dicom/imodelodicom.h>
 #include <main/controllers/controladorpermisos.h>
-#include <api/icontroladorimportacionpacs.h>
-#include <api/internacionalizacion.h>
+#include <api/controllers/ipacscontroller.h>
+
 #include <api/icontextoestudio.h>
+#include <api/internacionalization/internacionalization.h>
 
 #include "istorecallback.h"
 
@@ -35,6 +36,9 @@
 #include <dcmtk/dcmdata/dcdatset.h>
 #include <dcmtk/dcmdata/dcdeftag.h>
 
+#include <wx/string.h>
+#include <wx/intl.h>
+
 #include "tls/tls.h"
 #include "tls/gtlslayer.h"
 #include <dcmtk/dcmtls/tlstrans.h>
@@ -87,7 +91,7 @@ CONDITION MoveAssociation::moveSCU(DcmDataset *pdset) {
 	}
 
 	//sopClass = m_abstractSyntaxMove;
-	sopClass = m_abstractSyntax;
+	sopClass = m_abstractSyntax.c_str();
 
 	// which presentation context should be used
 	presId = ASC_findAcceptedPresentationContextID(assoc, sopClass);
@@ -133,7 +137,7 @@ CONDITION MoveAssociation::moveSCU(DcmDataset *pdset) {
 
 	if(m_errorMessage != "")
 	{
-		throw GIL::DICOM::PACSException(m_errorMessage, "Adquisition");
+		throw GIL::DICOM::PACSException(m_errorMessage, "Acquisition");
 	}
 
 	return cond;
