@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: i2d.cpp 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: i2d.cpp 3839 2011-05-11 08:47:59Z tovar $
  *  Ginkgo CADx Project
  *
  *  Code addapted from DCMTK
@@ -87,7 +87,7 @@ OFCondition Image2Dcm::convert(I2DImgSource *inputPlug,
 
 	OFCondition cond;
 	if (m_debug)
-		printMessage(m_logStream, "Image2Dcm: Starting conversion of file: ", inputPlug->getImageFile());
+		printMessage(m_logStream, "Image2Dcm: Starting conversion");
 
 	// If specified, copy DICOM template file to export file
 	if (m_templateFile.length() != 0) {
@@ -481,7 +481,6 @@ OFCondition Image2Dcm::generateUIDs(DcmDataset *dset)
 			std::srand((unsigned int)timestamp);
 
 			random_integer = lowest + int(range * rand()/(RAND_MAX + 1.0));
-			std::cout << random_integer << std::endl;
 
 			is << (unsigned long) timestamp;
 			is.width(4);
@@ -602,7 +601,7 @@ OFCondition Image2Dcm::readAndInsertPixelData(I2DImgSource* imgSource,
 		return cond;
 
 
-	if (imgSource->Recomprimir()) 
+	if (imgSource->Recompress()) 
 	{
 		// create initial pixel sequence
 		DcmElement* element = newDicomElement(DcmTag(DCM_PixelData, EVR_OW));
@@ -667,46 +666,61 @@ OFCondition Image2Dcm::readAndInsertPixelData(I2DImgSource* imgSource,
 
 		return cond;
 	} else {
-		DcmPixelSequence *pixelSequence = NULL;
+		if (imgSource->IsCompressed()) {
+			DcmPixelSequence *pixelSequence = NULL;
+
+			if (m_debug)
+				printMessage(m_logStream, "Image2Dcm: Store imported pixel data to DICOM file");
+			// create initial pixel sequence
+			pixelSequence = new DcmPixelSequence(DcmTag(DCM_PixelData, EVR_OB));
+			if (pixelSequence == NULL)
+				return EC_MemoryExhausted;
+			// insert empty offset table into sequence
+			DcmPixelItem *offsetTable = new DcmPixelItem(DcmTag(DCM_Item, EVR_OB));
+			if (offsetTable == NULL) {
+				delete pixelSequence;
+				pixelSequence = NULL;
+				return EC_MemoryExhausted;
+			}
+			cond = pixelSequence->insert(offsetTable);
+			if (cond.bad()) {
+				delete offsetTable;
+				offsetTable = NULL;
+				delete pixelSequence;
+				pixelSequence = NULL;
+				return cond;
+			}
+
+			// insert frame into pixel sequence
+			DcmOffsetList dummyList;
+			cond = pixelSequence->storeCompressedFrame(dummyList, (Uint8*) pixData, length, 0);
+			// storeCompressedFrame(..) does a deep copy, so the pixdata memory can be freed now
+			delete[] pixData;
+			if (cond.bad()) {
+				delete pixelSequence;
+				return cond;
+			}
+			cond = dset->insert(pixelSequence);
+			if (cond.bad())
+				delete pixelSequence;
+
+			if (m_debug)
+				printMessage(m_logStream, "Image2Dcm: Inserting Image Pixel module information");
+			return dset->putAndInsertUint16(DCM_PixelRepresentation, pixelRepr);
+		} else {
+			//little endian to little endian...
+			// create initial pixel sequence
+			DcmElement* element = newDicomElement(DcmTag(DCM_PixelData, EVR_OW));
+			element->putUint8Array((const Uint8*)pixData, length);
+			cond = dset->insert(element);
+			if (cond.bad()) {
+				delete element;
+				return cond;
+			}
+			outputTS = EXS_LittleEndianExplicit;
 
-		if (m_debug)
-			printMessage(m_logStream, "Image2Dcm: Store imported pixel data to DICOM file");
-		// create initial pixel sequence
-		pixelSequence = new DcmPixelSequence(DcmTag(DCM_PixelData, EVR_OB));
-		if (pixelSequence == NULL)
-			return EC_MemoryExhausted;
-		// insert empty offset table into sequence
-		DcmPixelItem *offsetTable = new DcmPixelItem(DcmTag(DCM_Item, EVR_OB));
-		if (offsetTable == NULL) {
-			delete pixelSequence;
-			pixelSequence = NULL;
-			return EC_MemoryExhausted;
-		}
-		cond = pixelSequence->insert(offsetTable);
-		if (cond.bad()) {
-			delete offsetTable;
-			offsetTable = NULL;
-			delete pixelSequence;
-			pixelSequence = NULL;
 			return cond;
 		}
-
-		// insert frame into pixel sequence
-		DcmOffsetList dummyList;
-		cond = pixelSequence->storeCompressedFrame(dummyList, (Uint8*) pixData, length, 0);
-		// storeCompressedFrame(..) does a deep copy, so the pixdata memory can be freed now
-		delete[] pixData;
-		if (cond.bad()) {
-			delete pixelSequence;
-			return cond;
-		}
-		cond = dset->insert(pixelSequence);
-		if (cond.bad())
-			delete pixelSequence;
-
-		if (m_debug)
-			printMessage(m_logStream, "Image2Dcm: Inserting Image Pixel module information");
-		return dset->putAndInsertUint16(DCM_PixelRepresentation, pixelRepr);
 	}
 }
 
