@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: streamingloader.cpp 3626 2011-03-25 10:16:40Z tovar $
+ *  $Id: streamingloader.cpp 3921 2011-07-06 11:36:02Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -12,24 +12,29 @@
  *
  */
 //#define _GINKGO_TRACE
-#include <api/globals.h>
-#include <api/icomando.h>
-#include <api/idicommanager.h>
-#include <api/icontroladorcomandos.h>
-#include <api/imodelointegracion.h>
-#include <main/entorno.h>
-#include <main/controllers/controladorlog.h>
-#include <commands/comandocarga.h>
-#include <eventos/eventosginkgo.h>
-#include "../controladoreventos.h"
-#include "../controladorvistas.h"
-#include "../controladorimportacionpacs.h"
-#include <api/icontextoestudio.h>
 
 #include <wx/filename.h>
 #include <wx/file.h>
 #include <wx/thread.h>
-#include <api/internacionalizacion.h>
+
+#include <api/globals.h>
+
+#include <api/icomando.h>
+#include <api/icontextoestudio.h>
+#include <api/dicom/idicommanager.h>
+#include <api/icontroladorcomandos.h>
+#include <api/imodelointegracion.h>
+
+#include <commands/comandocarga.h>
+
+#include <main/entorno.h>
+
+#include <main/controllers/controladorlog.h>
+#include <main/controllers/controladoreventos.h>
+#include <main/controllers/controladorvistas.h>
+#include <main/controllers/pacscontroller.h>
+
+#include <eventos/eventosginkgo.h>
 
 #include "streamingloader.h"
 
@@ -519,12 +524,12 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 		m_SignalFile = true;
 		
 		// Try to read as signal
-		GIL::DICOM::IDICOMManager* m = GIL::DICOM::ControladorImportacionPACS::Instance()->CrearInstanciaDeDICOMManager();
+		GIL::DICOM::IDICOMManager* m = GIL::DICOM::PACSController::Instance()->CrearInstanciaDeDICOMManager();
 		m->CargarFichero(m_CurrentFile);
 		std::string modality;
 		m->GetTag(0x0008, 0x0060, modality);
 		//TODO: Mantener esta lectura del dataset.
-		GIL::DICOM::ControladorImportacionPACS::Instance()->LiberarInstanciaDeDICOMManager(m);
+		GIL::DICOM::PACSController::Instance()->LiberarInstanciaDeDICOMManager(m);
 
 		if (modality == "ECG" || modality == "HD")
 		{
@@ -545,7 +550,7 @@ void GNC::StreamingLoader::SetInput(const std::string& fichero)
 		if (m_pReader) {
 			m_pReader->ResetPipeline();
 		}
-		throw GNC::GCS::ControladorCargaException( _Std("Internal error reading the study: "), "ControladorCarga/CargaMultidimensional");
+		throw GNC::GCS::ControladorCargaException( _Std("Internal error reading the study, unknown format "), "ControladorCarga/CargaMultidimensional");
 	}
 }
 
