@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguraciongeneral.cpp 3784 2011-04-27 12:07:33Z tovar $
+ *  $Id: panelconfiguraciongeneral.cpp 3896 2011-06-22 07:08:49Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -18,12 +18,12 @@
 #include <wx/msgout.h>
 #include <wx/dirdlg.h>
 #include <wx/filename.h>
-#include <wx/confbase.h>
+#include <main/controllers/configurationcontroller.h>
 #include <sstream>
 #include <wx/file.h>
 #include <wx/dir.h>
 #include <wx/xml/xml.h>
-#include <api/internacionalizacion.h>
+
 #include <wx/ginkgostyle/ginkgostyle.h>
 
 #include "panelconfiguraciongeneral.h"
@@ -62,26 +62,24 @@ namespace GNC {
 
 		void PanelConfiguracionGeneral::Recargar()
 		{
-			wxConfigBase * config = wxConfigBase::Get();
-			//se actualiza el fichero de configuracion
-			config->SetPath(wxT("/GinkgoCore/Estacion"));
-
-			wxString valor;
-
-			if(!config->Read(wxT("DicomDir"),&m_pathDicomDir,wxEmptyString)){
+			std::string dicomDir;
+			
+			if(!GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion","DicomDir", dicomDir)) {
 				m_pathDicomDir = FROMPATH(GNC::Entorno::Instance()->GetGinkgoDicomDir());
+			} else {
+				m_pathDicomDir = wxString::FromUTF8(dicomDir.c_str());
 			}
 			m_pDICOMDir->SetValue(m_pathDicomDir);
 
 			//check for updates
 			bool check;
-			config->Read(wxT("CheckForUpdates"),&check, true);
+			GNC::GCS::ConfigurationController::Instance()->readBoolGeneral("/GinkgoCore/Estacion", "CheckForUpdates", check, true);
 			m_pCheckForUpdates->SetValue(check);
 
+			
 			//internacionalizacion
-			config->SetPath(wxT("/GinkgoCore/Station"));
 			int language;
-			config->Read(wxT("Language"),&language,-1);
+			GNC::GCS::ConfigurationController::Instance()->readIntUser("/GinkgoCore/Station", "Language", language, true);
 
 			//explore lang directory to find installed languages
 			{
@@ -185,35 +183,30 @@ namespace GNC {
 
 		bool PanelConfiguracionGeneral::Guardar()
 		{
-			wxConfigBase * config = wxConfigBase::Get();
 			//se actualiza el fichero de configuracion
-			config->SetPath(wxT("/GinkgoCore/Estacion"));
-
 			wxFileName dirAnterior(m_pathDicomDir);
 			wxFileName dirNuevo(m_pDICOMDir->GetValue());
 			if(dirAnterior != dirNuevo)
 			{
+				GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Estacion", "DicomDir",std::string(m_pDICOMDir->GetValue().ToUTF8()));
 				//se vacia el dicomdir actual y se carga el nuevo...
-				config->Write(wxT("DicomDir"),m_pDICOMDir->GetValue());
 				GNC::Entorno::Instance()->RefrescarDicomDir();
 				GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoRecargarHistorial());
 			}
 
-			config->Write(wxT("CheckForUpdates"), m_pCheckForUpdates->GetValue());
+			GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/Estacion", "CheckForUpdates", m_pCheckForUpdates->GetValue());
 
-			//internacionalizacion
-			config->SetPath(wxT("/GinkgoCore/Station"));
-			
+			//internacionalizacion			
 			if (m_pComboLanguage->GetStringSelection() != _("Default")) {
 				std::string selectedLanguage(m_pComboLanguage->GetStringSelection().ToUTF8());
 				for (TMapLanguages::iterator it  = m_mapLanguages.begin(); it != m_mapLanguages.end(); ++it) {
 					if ((*it).first == selectedLanguage) {
-						config->Write(wxT("Language"),(*it).second);
+						GNC::GCS::ConfigurationController::Instance()->writeIntUser("/GinkgoCore/Station", "Language", (*it).second);
 						break;
 					}
 				}
 			} else {
-				config->DeleteEntry(wxT("Language"));
+				GNC::GCS::ConfigurationController::Instance()->deleteEntryUser("/GinkgoCore/Station", "Language");
 			}
 
 			return true;
@@ -269,7 +262,7 @@ namespace GNC {
 						}
 					}
 				}
-				nodo  = new wxXmlNode(pEstacion,wxXML_ELEMENT_NODE,wxT("Idioma"));
+				nodo  = new wxXmlNode(pEstacion,wxXML_ELEMENT_NODE,wxT("Language"));
 				new wxXmlNode(nodo,wxXML_TEXT_NODE,wxT(""),wxString::Format(wxT("%d"), language));
 			}
 
@@ -288,34 +281,32 @@ namespace GNC {
 			}
 
 			if(pEstacion != NULL) {
-				wxConfigBase * config = wxConfigBase::Get();
+				GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/Estacion", "CheckForUpdates");
+				GNC::GCS::ConfigurationController::Instance()->deleteEntryUser("/GinkgoCore/Station", "Language");
 				//se actualiza el fichero de configuracion
-				config->SetPath(wxT("/GinkgoCore/Estacion"));
-				config->DeleteEntry(wxT("Idioma"));
 				//si hay vistas abiertas no se cambia el dicomdir
 				if(GNC::GCS::ControladorVistas::Instance()->GetVistas().size() == 0)
 				{
-					config->DeleteEntry(wxT("DicomDir"));
+					GNC::GCS::ConfigurationController::Instance()->deleteEntryUser("/GinkgoCore/Estacion", "DicomDir");
 				}
 
 				for(wxXmlNode* pNodo = pEstacion->GetChildren(); pNodo!= NULL; pNodo =pNodo->GetNext())
 				{
-					config->SetPath(wxT("/GinkgoCore/Estacion"));
 					if(pNodo->GetChildren()!=NULL){
 						if(pNodo->GetName() == wxT("DicomDir")) {
 							//si hay vistas abiertas no se cambia el dicomdir
 							if(GNC::GCS::ControladorVistas::Instance()->GetVistas().size() == 0)
 							{
-								config->Write(wxT("DicomDir"),pNodo->GetChildren()->GetContent());
+								GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Estacion", "DicomDir", std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 								GNC::Entorno::Instance()->RefrescarDicomDir();
 								GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Eventos::EventoRecargarHistorial());
 							}
 						}
-						if(pNodo->GetName() == wxT("Idioma")) {
-							config->Write(wxT("Idioma"),pNodo->GetChildren()->GetContent());
+						if(pNodo->GetName() == wxT("Language")) {
+							GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/Station", "Language", std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 						}
 						if(pNodo->GetName() == wxT("CheckForUpdates")) {
-							config->Write(wxT("CheckForUpdates"),(pNodo->GetChildren()->GetContent() == wxT("true"))?true:false);
+							GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/Station", "CheckForUpdates", (pNodo->GetChildren()->GetContent() == wxT("true"))?true:false);
 						}
 					}
 				}
