@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionpacs.cpp 3787 2011-04-29 06:38:01Z tovar $
+ *  $Id: panelconfiguracionpacs.cpp 3917 2011-07-05 09:30:55Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -25,7 +25,7 @@
 #include <wx/msgdlg.h>
 #include <wx/msgout.h>
 #include <wx/filename.h>
-#include <wx/confbase.h>
+#include <main/controllers/configurationcontroller.h>
 #include <wx/valtext.h>
 #include <wx/ginkgostyle/ginkgostyle.h>
 
@@ -36,7 +36,7 @@
 #include <wx/log.h>
 #include <wx/busyinfo.h>
 #include <wx/xml/xml.h>
-#include <api/internacionalizacion.h>
+
 
 #include "panelconfiguracionpacs.h"
 
@@ -287,8 +287,10 @@ namespace GNC {
 		class DialogoServidorPACS: public DialogoServidorPACSBase
 		{
 		public:
-			DialogoServidorPACS(wxWindow* pParent, PanelConfiguracionPACS::TipoConfigLocal& configLocal, const wxString& strPuertoLocal, const wxString& aetLocal) : DialogoServidorPACSBase(pParent), m_configLocal(configLocal)
+			DialogoServidorPACS(wxWindow* pParent, PanelConfiguracionPACS::TipoConfigLocal& configLocal, const wxString& strPuertoLocal, const wxString& aetLocal, std::list<std::string> usedPACSIds) : DialogoServidorPACSBase(pParent), m_configLocal(configLocal)
 			{
+				m_Ok = false;
+				m_idsPacs = usedPACSIds;
 				wxTextValidator OnlyNum = wxTextValidator(wxFILTER_NUMERIC);
 				m_pPuerto->SetValidator(OnlyNum);
 
@@ -397,6 +399,15 @@ namespace GNC {
 					std::stringstream sstream;
 					sstream << _Std("There are this errors: ");
 
+					std::string idPACS = std::string(m_pId->GetValue().ToUTF8());
+					for (std::list<std::string>::iterator it = m_idsPacs.begin(); it != m_idsPacs.end(); ++it) {
+						if (idPACS == (*it)) {
+							sstream << _Std("\n- This PACS id is in use");
+							ok = false;
+							break;
+						}
+					}
+
 					long numero;
 					if(!m_pPuerto->GetValue().ToLong(&numero)){
 						ok = false;
@@ -524,6 +535,7 @@ namespace GNC {
 			long m_puertoLocal;
 			std::string m_certificado;
 			std::string m_privateKey;
+			std::list<std::string> m_idsPacs;
 		};
 
 
@@ -557,17 +569,12 @@ namespace GNC {
 
 		void PanelConfiguracionPACS::Recargar()
 		{
-			wxConfigBase * config = wxConfigBase::Get();
-			//se actualiza el fichero de configuracion
-
-			config->SetPath(wxT("/GinkgoCore/PACS/Local"));
-
-			wxString valor;
-			if(!config->Read(wxT("AET"),&valor,wxT("GINKGO_%IP4"))){
-				config->Write(wxT("AET"),valor);
+			std::string strTmp;
+			if (!GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/PACS/Local", "AET", strTmp, "GINKGO_%IP4")) {
+				GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local", "AET", strTmp);
 			}
-			m_pAETLocal->SetValue(valor);
-			m_pAETReal->SetLabel(wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET(std::string(valor.ToUTF8())).substr(0, 16).c_str() ));
+			m_pAETLocal->SetValue(wxString::FromUTF8(strTmp.c_str()));
+			m_pAETReal->SetLabel(wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET(strTmp).substr(0, 16).c_str() ));
 
 			DicomServer* serverLocal = DicomServerList::Instance()->GetLocalServer();
 			m_pPuertoLocal->SetValue(wxString::Format(wxT("%d"),serverLocal->GetPort()));
@@ -675,73 +682,38 @@ namespace GNC {
 
 		bool PanelConfiguracionPACS::Guardar()
 		{
-			wxConfigBase * config = wxConfigBase::Get();
 			//se actualiza el fichero de configuracion
-
-			config->SetPath(wxT("/GinkgoCore/PACS/Local"));
-
-			config->Write(wxT("AET"),m_pAETLocal->GetValue());
-			config->Write(wxT("Puerto"),m_pPuertoLocal->GetValue());
-
-			//local advanced
-			config->Write(wxT("useTLS"),m_configLocal.useTLS);
-			config->Write(wxT("verifyCredentials"), m_configLocal.verifyCredentials);
-			config->Write(wxT("privateKey"), wxString::FromUTF8(m_configLocal.privateKey.c_str()));
-			config->Write(wxT("certificate"), wxString::FromUTF8(m_configLocal.certificate.c_str()));
-
-			config->DeleteGroup(wxT("/GinkgoCore/PACS/Servidores"));
-			config->SetPath(wxT("/GinkgoCore/PACS/Servidores"));
-
+			GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","AET",std::string(m_pAETLocal->GetValue().ToUTF8()));
+			GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","Puerto",std::string(m_pPuertoLocal->GetValue().ToUTF8()));
+			GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/PACS/Local","useTLS",m_configLocal.useTLS);
+			GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/PACS/Local","verifyCredentials",m_configLocal.verifyCredentials);
+			GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","privateKey",m_configLocal.privateKey);
+			GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","certificate",m_configLocal.certificate);
+			
 			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.pacs.limits","remote_pacs")) {
-				int i=0;
 				wxString clave;
 				wxString valor;
-				for(TipoListaPACS::iterator it = m_servidores.begin(); it!= m_servidores.end(); it++,i++){
-					clave = wxString::Format(wxT("Servidor%d/Identificador"),i);
-					valor = wxString::FromUTF8((*it).id.c_str());
-					config->Write(clave,valor);
+				GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/PACS/Servidores");
+				GNC::GCS::ConfigurationController::TListGroups pacsList;
 
-					clave = wxString::Format(wxT("Servidor%d/AET"),i);
-					valor = wxString::FromUTF8((*it).aet.c_str());
-					config->Write(clave,valor);
-
-					clave = wxString::Format(wxT("Servidor%d/Host"),i);
-					valor = wxString::FromUTF8((*it).host.c_str());
-					config->Write(clave,valor);
-
-					clave = wxString::Format(wxT("Servidor%d/Puerto"),i);
-					config->Write(clave,(*it).puerto);
-
-					clave = wxString::Format(wxT("Servidor%d/PDU"),i);
-					config->Write(clave,(*it).pdu);
-
-					clave = wxString::Format(wxT("Servidor%d/isDefault"),i);
-					config->Write(clave,(*it).isDefault);
-
-					clave = wxString::Format(wxT("Servidor%d/useTLS"),i);
-					config->Write(clave,(*it).useTLS);
-
-					clave = wxString::Format(wxT("Servidor%d/pacsUser"),i);
-					config->Write(clave,wxString::FromUTF8((*it).pacsUser.c_str()) );
-
-					clave = wxString::Format(wxT("Servidor%d/pacsPass"),i);
-					config->Write(clave,wxString::FromUTF8((*it).pacsPass.c_str()) );
-					
-					clave = wxString::Format(wxT("Servidor%d/verifyCredentials"),i);
-					config->Write(clave,(*it).verifyCredentials);
-					
-					clave = wxString::Format(wxT("Servidor%d/certificate"),i);
-					config->Write(clave,wxString::FromUTF8((*it).certificate.c_str()) );
-					
-					clave = wxString::Format(wxT("Servidor%d/privateKey"),i);
-					config->Write(clave,wxString::FromUTF8((*it).privateKey.c_str()) );
-					
-					clave = wxString::Format(wxT("Servidor%d/retrieveWithMove"),i);
-					config->Write(clave,(*it).retrieveWithMove );
-
-					clave = wxString::Format(wxT("Servidor%d/retrieveSeries"),i);
-					config->Write(clave,(*it).retrieveSeries );
+				for(TipoListaPACS::iterator it = m_servidores.begin(); it!= m_servidores.end(); it++){
+					GNC::GCS::ConfigurationController::TMapValues pacs;
+					pacs["Identificador"] = (*it).id;
+					pacs["AET"] = (*it).aet;
+					pacs["Host"] = (*it).host;
+					pacs.insertInt("Puerto",(*it).puerto);
+					pacs.insertInt("PDU",(*it).pdu);
+					pacs.insertBool("useTLS", (*it).useTLS);
+					pacs.insertBool("verifyCredentials", (*it).verifyCredentials);
+					pacs.insertBool("retrieveWithMove", (*it).retrieveWithMove);
+					pacs.insertBool("retrieveSeries", (*it).retrieveSeries);
+					pacs["pacsUser"] = (*it).pacsUser;
+					pacs["pacsPass"] = (*it).pacsPass;
+					pacs["certificate"] = (*it).certificate;
+					pacs["privateKey"] = (*it).privateKey;
+					pacsList.push_back(pacs);
 				}
+				GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/PACS/Servidores", pacsList, "Server");
 				DicomServerList::Instance()->Reload();
 			}
 			else {
@@ -827,12 +799,8 @@ namespace GNC {
 
 		void PanelConfiguracionPACS::Importar(wxXmlNode* pNodo)
 		{
-			wxConfigBase * config = wxConfigBase::Get();
 			//se actualiza el fichero de configuracion
-
-			config->SetPath(wxT("/GinkgoCore/PACS/Local"));
-			config->DeleteEntry(wxT("AET"));
-			config->DeleteEntry(wxT("Puerto"));
+			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/PACS/Local");
 
 			wxXmlNode* pPACS = NULL;
 			for(pPACS = pNodo->GetChildren(); pPACS != NULL; pPACS = pPACS->GetNext()) {
@@ -848,44 +816,42 @@ namespace GNC {
 					}
 				}
 				if(pLocal != NULL) {
-					config->SetPath(wxT("/GinkgoCore/PACS/Local"));
 					for(wxXmlNode* pNodo = pLocal->GetChildren(); pNodo!= NULL; pNodo =pNodo->GetNext())
 					{
 						if(pNodo->GetChildren() != NULL) {
 							if(pNodo->GetName() == wxT("AET")) {
-								config->Write(wxT("AET"),pNodo->GetChildren()->GetContent());
+								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","AET",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 							}
 							if(pNodo->GetName() == wxT("Puerto")) {
-								config->Write(wxT("Puerto"),pNodo->GetChildren()->GetContent());
+								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","Puerto",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 							}
 							if(pNodo->GetName() == wxT("useTLS")) {
-								config->Write(wxT("useTLS"),pNodo->GetChildren()->GetContent()==wxT("true"));
+								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","useTLS",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 							}
 							if(pNodo->GetName() == wxT("useUserPass")) {
-								config->Write(wxT("useUserPass"),pNodo->GetChildren()->GetContent()==wxT("true"));
+								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","useUserPass",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 							}
 							if(pNodo->GetName() == wxT("pacsUser")) {
-								config->Write(wxT("pacsUser"),pNodo->GetChildren()->GetContent());
+								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","pacsUser",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 							}
 							if(pNodo->GetName() == wxT("pacsPass")) {
-								config->Write(wxT("pacsPass"),pNodo->GetChildren()->GetContent());
+								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","pacsPass",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 							}
 							if(pNodo->GetName() == wxT("verifyCredentials")) {
-								config->Write(wxT("verifyCredentials"),pNodo->GetChildren()->GetContent()==wxT("true"));
+								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","verifyCredentials",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 							}
 							if(pNodo->GetName() == wxT("privateKey")) {
-								config->Write(wxT("privateKey"),pNodo->GetChildren()->GetContent());
+								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","privateKey",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 							}
 							if(pNodo->GetName() == wxT("certificate")) {
-								config->Write(wxT("certificate"),pNodo->GetChildren()->GetContent());
+								GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/PACS/Local","certificate",std::string(pNodo->GetChildren()->GetContent().ToUTF8()));
 							}
 						}
 					}
 				}
 			}
 
-			config->DeleteGroup(wxT("/GinkgoCore/PACS/Servidores"));
-			config->SetPath(wxT("/GinkgoCore/PACS/Servidores"));
+			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/PACS/Servidores");
 
 			for(pPACS = pNodo->GetChildren(); pPACS != NULL; pPACS = pPACS->GetNext()) {
 				if(pPACS->GetName() == wxT("PACS")) {
@@ -902,6 +868,9 @@ namespace GNC {
 				if(pServidores != NULL) {
 					int i=0;
 					wxString clave;
+
+					GNC::GCS::ConfigurationController::TListGroups pacsList;
+
 					for(wxXmlNode* pTag=pServidores->GetChildren(); pTag!=NULL; pTag = pTag->GetNext(),i++) {
 						wxString identificador;
 						pTag->GetPropVal(wxT("Identificador"),&identificador);
@@ -939,45 +908,23 @@ namespace GNC {
 						tmpStr = pTag->GetPropVal(wxT("retrieveSeries"),wxT("true"));
 						pacsTmp.retrieveSeries = tmpStr == wxT("true");
 
-						clave = wxString::Format(wxT("Servidor%d/Identificador"),i);
-						config->Write(clave,identificador);
-
-						clave = wxString::Format(wxT("Servidor%d/AET"),i);
-						config->Write(clave,aet);
-
-						clave = wxString::Format(wxT("Servidor%d/Host"),i);
-						config->Write(clave,host);
-
-						clave = wxString::Format(wxT("Servidor%d/Puerto"),i);
-						config->Write(clave,puerto);
-
-						clave = wxString::Format(wxT("Servidor%d/PDU"),i);
-						config->Write(clave,pdu);
-
-						clave = wxString::Format(wxT("Servidor%d/useTLS"),i);
-						config->Write(clave,pacsTmp.useTLS);
-
-						clave = wxString::Format(wxT("Servidor%d/pacsUser"),i);
-						config->Write(clave,wxString::FromUTF8(pacsTmp.pacsUser.c_str()));
-
-						clave = wxString::Format(wxT("Servidor%d/pacsPass"),i);
-						config->Write(clave,wxString::FromUTF8(pacsTmp.pacsPass.c_str()));
-						
-						clave = wxString::Format(wxT("Servidor%d/verifyCredentials"),i);
-						config->Write(clave,pacsTmp.verifyCredentials);
-						
-						clave = wxString::Format(wxT("Servidor%d/certificate"),i);
-						config->Write(clave,wxString::FromUTF8(pacsTmp.certificate.c_str()) );
-
-						clave = wxString::Format(wxT("Servidor%d/privateKey"),i);
-						config->Write(clave,wxString::FromUTF8(pacsTmp.privateKey.c_str()) );
-						
-						clave = wxString::Format(wxT("Servidor%d/retrieveWithMove"),i);
-						config->Write(clave,pacsTmp.retrieveWithMove );
-
-						clave = wxString::Format(wxT("Servidor%d/retrieveSeries"),i);
-						config->Write(clave,pacsTmp.retrieveSeries );
+						GNC::GCS::ConfigurationController::TMapValues pacs;
+						pacs["Identificador"] = identificador.ToUTF8();
+						pacs["AET"] = aet.ToUTF8();
+						pacs["Host"] = host.ToUTF8();
+						pacs["Puerto"] = puerto.ToUTF8();
+						pacs["PDU"] = pdu.ToUTF8();
+						pacs.insertBool("useTLS", pacsTmp.useTLS);
+						pacs.insertBool("verifyCredentials", pacsTmp.verifyCredentials);
+						pacs.insertBool("retrieveWithMove", pacsTmp.retrieveWithMove);
+						pacs.insertBool("retrieveSeries", pacsTmp.retrieveSeries);
+						pacs["pacsUser"] = pacsTmp.pacsUser;
+						pacs["pacsPass"] = pacsTmp.pacsPass;
+						pacs["certificate"] = pacsTmp.certificate;
+						pacs["privateKey"] = pacsTmp.privateKey;
+						pacsList.push_back(pacs);
 					}
+					GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/PACS/Servidores", pacsList, "Server");
 				}
 			}
 			DicomServerList::Instance()->Reload();
@@ -1010,7 +957,11 @@ namespace GNC {
 		}
 
 		void PanelConfiguracionPACS::OnNuevoClick(wxCommandEvent &){
-			DialogoServidorPACS dialogo(this, m_configLocal, m_pPuertoLocal->GetValue(), wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET( std::string(m_pAETLocal->GetValue().ToUTF8()) ).c_str() ) );
+			std::list<std::string> listIdsPacs;
+			for (TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it) {
+				listIdsPacs.push_back((*it).id);
+			}
+			DialogoServidorPACS dialogo(this, m_configLocal, m_pPuertoLocal->GetValue(), wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET( std::string(m_pAETLocal->GetValue().ToUTF8()) ).c_str() ), listIdsPacs );
 			dialogo.ShowModal();
 			if(dialogo.m_Ok){
 				TipoPACS tp;
@@ -1039,9 +990,16 @@ namespace GNC {
 			if(id.IsOk()){
 				std::string idSeleccionado(m_pTreeListPACS->GetItemText(id).ToUTF8());
 
+				std::list<std::string> listIdsPacs;
+				for (TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); ++it) {
+					if((*it).id != idSeleccionado){
+						listIdsPacs.push_back((*it).id);
+					}
+				}
+
 				for(TipoListaPACS::iterator it = m_servidores.begin(); it != m_servidores.end(); it++){
 					if((*it).id == idSeleccionado){
-						DialogoServidorPACS dialogo(this, m_configLocal, m_pPuertoLocal->GetValue(), wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET( std::string( m_pAETLocal->GetValue().ToUTF8() ) ).c_str() ) );
+						DialogoServidorPACS dialogo(this, m_configLocal, m_pPuertoLocal->GetValue(), wxString::FromUTF8( GNC::Entorno::Instance()->ParseAET( std::string( m_pAETLocal->GetValue().ToUTF8() ) ).c_str() ), listIdsPacs);
 						dialogo.SetParametros((*it));
 
 						dialogo.ShowModal();
