@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: panelconfiguracionubicaciones.cpp 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: panelconfiguracionubicaciones.cpp 3893 2011-06-21 13:01:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -18,7 +18,7 @@
 #include <wx/msgdlg.h>
 #include <wx/msgout.h>
 #include <wx/filename.h>
-#include <wx/confbase.h>
+#include <main/controllers/configurationcontroller.h>
 #include <wx/valtext.h>
 #include <wx/ginkgostyle/ginkgostyle.h>
 #include <wx/mstream.h>
@@ -29,7 +29,7 @@
 #include <wx/log.h>
 #include <wx/xml/xml.h>
 #include <wx/log.h>
-#include <api/internacionalizacion.h>
+
 #include <wx/tokenzr.h>
 
 #include "panelconfiguracionubicaciones.h"
@@ -416,29 +416,16 @@ namespace GNC {
 
 		void PanelConfiguracionUbicaciones::Recargar()
 		{
-			wxConfigBase * config = wxConfigBase::Get();
+			GNC::GCS::ConfigurationController::TListGroups locations;
+			GNC::GCS::ConfigurationController::Instance()->readGroupGeneral("/GinkgoCore/Locations", locations);
 
 			m_pUbicacionesGridTable->Clear();
-
-			config->SetPath(wxT("/GinkgoCore/Locations"));
-			wxString str;
-
-			long dummy = 0;
-
-			bool bCont = config->GetFirstGroup(str, dummy);
-			while ( bCont ) {
-				config->SetPath(str);
-				config->Read(wxT("Title"),&str);
-				std::string titulo(str.ToUTF8());
-				config->Read(wxT("Path"),&str);
-				std::string path(str.ToUTF8());
-				config->Read(wxT("Description"),&str);
-				std::string descr(str.ToUTF8());
-
-				m_pUbicacionesGridTable->AddUbicacion(titulo, path, descr);
-
-				config->SetPath(wxT(".."));
-				bCont = config->GetNextGroup(str, dummy);
+			for (GNC::GCS::ConfigurationController::TListGroups::iterator it = locations.begin(); it != locations.end(); ++it) {
+				std::string title, path, descr;
+				(*it).readStringValue("Title", title);
+				(*it).readStringValue("Path", path);
+				(*it).readStringValue("Description", descr);
+				m_pUbicacionesGridTable->AddUbicacion(title, path, descr);
 			}
 		}
 
@@ -470,29 +457,20 @@ namespace GNC {
 			GNC::GCS::IEntorno::MapaUbicaciones& mapa = GNC::Entorno::Instance()->GetUbicaciones();
 			mapa.clear();
 
-			wxConfigBase * config = wxConfigBase::Get();
-			//se actualiza el fichero de configuracion
+			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/Locations");
+			GNC::GCS::ConfigurationController::TListGroups locations;
 
-			config->DeleteGroup(wxT("/GinkgoCore/Locations"));
-			config->SetPath(wxT("/GinkgoCore/Locations"));
-			int i=0;
-			wxString clave;
-			wxString valor;
-			for (GNC::GCS::IEntorno::MapaUbicaciones::iterator it = m_pUbicacionesGridTable->m_Ubicaciones.begin(); it != m_pUbicacionesGridTable->m_Ubicaciones.end(); it++, i++) {
+			for (GNC::GCS::IEntorno::MapaUbicaciones::iterator it = m_pUbicacionesGridTable->m_Ubicaciones.begin(); it != m_pUbicacionesGridTable->m_Ubicaciones.end(); it++) {
 				GIL::Ubicacion& u = (*it).second;
 				mapa[u.Titulo] = u;
-				clave = wxString::Format(wxT("Location%d/Title"),i);
-				valor = wxString::FromUTF8(u.Titulo.c_str());
-				config->Write(clave,valor);
-
-				clave = wxString::Format(wxT("Location%d/Path"),i);
-				valor = wxString::FromUTF8(u.Ruta.c_str());
-				config->Write(clave, valor);
-
-				clave = wxString::Format(wxT("Location%d/Description"),i);
-				valor = wxString::FromUTF8(u.Descripcion.c_str());
-				config->Write(clave, valor);
+				GNC::GCS::ConfigurationController::TMapValues location;
+				location["Title"] = u.Titulo;
+				location["Path"] = u.Ruta;
+				location["Description"] = u.Descripcion;
+				locations.push_back(location);
 			}
+			GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/Locations", locations, "Location");
+
 			return true;
 		}
 
@@ -524,11 +502,8 @@ namespace GNC {
 		{
 			GNC::GCS::IEntorno::MapaUbicaciones& mapa = GNC::Entorno::Instance()->GetUbicaciones();
 			mapa.clear();
-			wxConfigBase * config = wxConfigBase::Get();
-			//se actualiza el fichero de configuracion
-
-			config->DeleteGroup(wxT("/GinkgoCore/Locations"));
-			config->SetPath(wxT("/GinkgoCore/Locations"));
+			
+			GNC::GCS::ConfigurationController::Instance()->deleteEntryGeneral("/GinkgoCore/Locations");
 
 			wxXmlNode* pLocations = NULL;
 			for(pLocations = pNodo->GetChildren(); pLocations!= NULL; pLocations = pLocations->GetNext()) {
@@ -540,6 +515,7 @@ namespace GNC {
 				int i=0;
 				wxString clave;
 
+				GNC::GCS::ConfigurationController::TListGroups locations;
 				for(wxXmlNode* pTag = pLocations->GetChildren(); pTag != NULL; pTag = pTag->GetNext(), i++) {
 
 					wxString titulo;
@@ -552,15 +528,13 @@ namespace GNC {
 					GIL::Ubicacion u (std::string(titulo.ToUTF8()), std::string(ruta.ToUTF8()), std::string(descripcion.ToUTF8()));
 					mapa[u.Titulo] = u;
 
-					clave = wxString::Format(wxT("Location%d/Title"),i);
-					config->Write(clave, titulo);
-
-					clave = wxString::Format(wxT("Location%d/Path"),i);
-					config->Write(clave, ruta);
-
-					clave = wxString::Format(wxT("Location%d/Description"),i);
-					config->Write(clave, descripcion);
+					GNC::GCS::ConfigurationController::TMapValues location;
+					location["Title"] = u.Titulo;
+					location["Path"] = u.Ruta;
+					location["Description"] = u.Descripcion;
+					locations.push_back(location);
 				}
+				GNC::GCS::ConfigurationController::Instance()->writeGroupGeneral("/GinkgoCore/Locations", locations, "Location");
 			}
 		}
 
