@@ -1,6 +1,6 @@
 /*
 *  
-*  $Id: dicombrowsercomponent.cpp 3648 2011-04-04 11:56:18Z tovar $
+*  $Id: dicombrowsercomponent.cpp 3893 2011-06-21 13:01:56Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -20,11 +20,11 @@
 #include <wx/filedlg.h>
 #include <wx/menu.h>
 #include <wx/dirdlg.h>
-#include <wx/confbase.h>
+#include <main/controllers/configurationcontroller.h>
 #include <wx/msgdlg.h>
 #include "dicombrowsercomponent.h"
 
-#include <api/internacionalizacion.h>
+
 
 #include <vector>
 #include <sstream>
@@ -32,9 +32,9 @@
 #include <main/entorno.h>
 #include <main/controllers/controladorextensiones.h>
 #include <main/controllers/controladorcomandos.h>
-#include <main/controllers/controladorimportacionpacs.h>
+#include <main/controllers/pacscontroller.h>
 #include <commands/comandoincluirhistorial.h>
-#include <api/imodelodicom.h>
+#include <api/dicom/imodelodicom.h>
 #include <resources/ginkgoresourcemanager.h>
 #include <api/icontextoestudio.h>
 
@@ -562,7 +562,7 @@ namespace GNC {
 				PopUpMenuDescargar(DicomBrowserComponent* pPaso):wxMenu()
 				{
 					m_pPaso = pPaso;
-					wxMenuItem* del = new wxMenuItem( this,wxID_ANY,_("Add"));
+					wxMenuItem* del = new wxMenuItem( this,wxID_ANY,_("Remove"));
 					Append(del);
 
 					Connect(del->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( PopUpMenuDescargar::OnDel ),NULL,this);
@@ -649,7 +649,7 @@ namespace GNC {
 		void DicomBrowserComponent::HelperCopiaEnProfundidad(const wxTreeItemId& padreDer, const wxTreeItemId& padreIzq)
 		{
 			wxTreeItemIdValue cookie;
-			wxTreeItemId actualIzq = m_pTreeListDer->GetFirstChild(padreIzq,cookie);
+			wxTreeItemId actualIzq = m_pTreeListIzq->GetFirstChild(padreIzq,cookie);
 			wxTreeItemId actualDer;
 			while ( actualIzq.IsOk() ) {
 				//se copia el hijo...
