@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelhistorial2.cpp 3710 2011-04-15 10:29:01Z tovar $
+ *  $Id: panelhistorial2.cpp 3933 2011-07-07 07:40:00Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -21,7 +21,7 @@
 #include <wx/textfile.h>
 #include <wx/imaglist.h>
 #include <wx/menu.h>
-#include <wx/config.h>
+#include <main/controllers/configurationcontroller.h>
 #include <wx/busyinfo.h>
 #include <wx/bmpcbox.h>
 #include <wx/ginkgostyle/ginkgostyle.h>
@@ -32,10 +32,10 @@
 #include "panelestudio.h"
 #include "dialogoconfirmacioneliminar.h"
 #include <main/gui/import/wxwizardimportacionginkgo.h>
-#include <main/gui/adquisition/dialogoadquisicion.h>
+#include <main/gui/acquisition/dialogoadquisicion.h>
 #include <main/gui/open/abrir.h>
 
-#include <api/idicommanager.h>
+#include <api/dicom/imodelodicom.h>
 #include <eventos/eventosginkgo.h>
 
 #include <main/entorno.h>
@@ -45,13 +45,13 @@
 #include <main/controllers/controladorhistorial.h>
 #include <commands/comandoincluirhistorial.h>
 #include <api/icontroladorcomandos.h>
-#include <api/internacionalizacion.h>
+
 #include <api/icontextoestudio.h>
 #include <resources/ginkgoresourcemanager.h>
 
 #include <sstream>
 
-#include <api/imodelodicom.h>
+#include <api/dicom/imodelodicom.h>
 
 
 #define ID_MENUS 1401
@@ -143,20 +143,19 @@ namespace GNC {
 		PanelHistorial2::~PanelHistorial2() {
 			//stores filter state
 			{
-				wxConfigBase * config = wxConfigBase::Get();
-				config->SetPath(wxT("/GinkgoCore/History"));
-				config->Write(wxT("PatientComboValue"),m_pComboBoxPaciente->GetValue());
-				config->Write(wxT("ModalityValue"),m_pComboModalidad->GetValue());
-				config->Write(wxT("DateChoice") , m_pComboDate->GetSelection());
+				GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/History", "PatientComboValue", std::string(m_pComboBoxPaciente->GetValue().ToUTF8()));
+				GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/History", "ModalityValue", std::string(m_pComboModalidad->GetValue().ToUTF8()));
+				GNC::GCS::ConfigurationController::Instance()->writeIntUser("/GinkgoCore/History", "DateChoice", m_pComboDate->GetSelection());
 				if (m_fromActual.IsValid()) {
-					config->Write(wxT("DateFrom"), m_fromActual.Format(wxT("%Y/%m/%d")));
+					GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/History", "DateFrom", std::string(m_fromActual.Format(wxT("%Y/%m/%d")).ToUTF8()));
 				} else {
-					config->DeleteEntry(wxT("DateFrom"));
+					GNC::GCS::ConfigurationController::Instance()->deleteEntryUser("/GinkgoCore/History", "DateFrom");
 				}
+
 				if (m_toActual.IsValid()) {
-					config->Write(wxT("DateTo"), m_toActual.Format(wxT("%Y/%m/%d")));
+					GNC::GCS::ConfigurationController::Instance()->writeStringUser("/GinkgoCore/History", "DateTo", std::string(m_toActual.Format(wxT("%Y/%m/%d")).ToUTF8()));
 				} else {
-					config->DeleteEntry(wxT("DateTo"));
+					GNC::GCS::ConfigurationController::Instance()->deleteEntryUser("/GinkgoCore/History", "DateTo");
 				}
 			}
 
@@ -234,34 +233,32 @@ namespace GNC {
 
 			if (comprobarPurga) {
 				//load filter state
-				wxConfigBase * config = wxConfigBase::Get();
-				config->SetPath(wxT("/GinkgoCore/History"));
-				wxString tmp;
-				if ( config->Read(wxT("PatientComboValue"), &tmp, wxEmptyString) ) {
-					int pos = m_pComboBoxPaciente->FindString(tmp);
+				std::string strTmp;
+				if (GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/History", "PatientComboValue", strTmp)) {
+					int pos = m_pComboBoxPaciente->FindString(wxString::FromUTF8(strTmp.c_str()));
 					if (pos >= 0) {
 						m_pComboBoxPaciente->Select(pos);
 					}
 				}
-				if ( config->Read(wxT("ModalityValue"), &tmp) ) {
-					int pos = m_pComboModalidad->FindString(tmp);
+				if (GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/History", "ModalityValue", strTmp)) {
+					int pos = m_pComboModalidad->FindString(wxString::FromUTF8(strTmp.c_str()));
 					if (pos >= 0) {
 						m_pComboModalidad->Select(pos);
 					}
 				}
 				int intTmp;
-				if (config->Read(wxT("DateChoice"), &intTmp)) {
+				if (GNC::GCS::ConfigurationController::Instance()->readIntUser("/GinkgoCore/History", "DateChoice", intTmp)) {
 					m_pComboDate->Select(intTmp);
 				}
 				if (m_pComboDate->GetValue() == _("Between:")) {
-					if (config->Read(wxT("DateFrom"), &tmp)) {
+					if (GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/History", "DateFrom", strTmp)) {
 						wxDateTime from;
-						from.ParseFormat(tmp, wxT("%Y/%m/%d"),wxDateTime::Now());
+						from.ParseFormat(wxString::FromUTF8(strTmp.c_str()), wxT("%Y/%m/%d"),wxDateTime::Now());
 						m_pDatePickerFrom->SetValue(from);
 					}
-					if (config->Read(wxT("DateTo"), &tmp)) {
+					if (GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/History", "DateTo", strTmp)) {
 						wxDateTime to;
-						to.ParseFormat(tmp, wxT("%Y/%m/%d"),wxDateTime::Now());
+						to.ParseFormat(wxString::FromUTF8(strTmp.c_str()), wxT("%Y/%m/%d"),wxDateTime::Now());
 						m_pDatePickerTo->SetValue(to);
 					}
 				}
@@ -911,7 +908,7 @@ namespace GNC {
 			m_pCabeceraVacio->SetLabel(_("\nThere aren't any stored study that matches with the search filter.\n"));
 			m_pCabeceraVacio->Wrap(event.GetSize().x-20);
 
-			m_pMensajeVacio->SetLabel(_("\nTo begin working must change filter criteria, acquire an existing study or Import DICOM images to DICOM format.\n"));
+			m_pMensajeVacio->SetLabel(_("\nTo begin working must change filter criteria, acquire an existing study or import images in DICOM format.\n"));
 			m_pMensajeVacio->Wrap(event.GetSize().x-20);
 
 			m_pCabeceraNoCabeMas->SetLabel(_("\nThere is no size in the medical history to show every patients\n"));
@@ -929,18 +926,6 @@ namespace GNC {
 		void PanelHistorial2::OnMenuMouse(wxMouseEvent &event)
 		{
 			wxMenu menu(wxEmptyString);
-			wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 1, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
-			menu.Connect(1,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelHistorial2::OnLimpiarHistorial),NULL,this);
-			#ifdef __WXMSW__
-			pMenuEliminar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
-			#else
-			pMenuEliminar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
-			#endif
-			menu.Append(pMenuEliminar);
-			if(m_mapaHijos.size() == 0) {
-				pMenuEliminar->Enable(false);
-			}
-			menu.AppendSeparator();
 
 			wxMenuItem* pMenuAdquirir = new wxMenuItem(&menu, 3, wxString( _("&DICOM &Acquisition") ), _("Acquiring a new DICOM study"), wxITEM_NORMAL );
 			menu.Connect(3,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelPaciente::OnAdquirir),NULL,this);
@@ -957,7 +942,6 @@ namespace GNC {
 			wxMenuItem* pMenuSend = new wxMenuItem(&menu, 7, wxString( _("Send to PACS server") ), _("Send to PACS server"), wxITEM_NORMAL );
 			menu.Connect(7,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelPaciente::OnUploadPACS),NULL,this);
 
-
 			#ifdef __WXMSW__
 			pMenuAdquirir->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoAbrir());
 			pMenuImportar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoImportar());
@@ -981,9 +965,26 @@ namespace GNC {
 				delete pMenuAdquirir;
 			}
 			menu.AppendSeparator();
-			menu.Append(pMenuSend);
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.menu","subir pacs")) {
+				menu.Append(pMenuSend);
+			} else {
+				delete pMenuSend;
+			}
 			menu.AppendSeparator();
 			menu.Append(pMenuImportar);
+
+			menu.AppendSeparator();
+			wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 1, wxString( _("&Clear History") ), _("Delete"), wxITEM_NORMAL );
+			menu.Connect(1,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelHistorial2::OnLimpiarHistorial),NULL,this);
+			#ifdef __WXMSW__
+			pMenuEliminar->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+			#else
+			pMenuEliminar->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoEliminar());
+			#endif
+			menu.Append(pMenuEliminar);
+			if(m_mapaHijos.size() == 0) {
+				pMenuEliminar->Enable(false);
+			}
 			PopupMenu(&menu);
 			event.Skip(false);
 		}
@@ -1149,7 +1150,7 @@ namespace GNC {
 						GNC::GCS::Eventos::EventoAddFicheroHistorial* pEvtMod = dynamic_cast<GNC::GCS::Eventos::EventoAddFicheroHistorial*>(evt);
 						if(pEvtMod != NULL){
 							//se lanza el comando de incluir en el historial
-							GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams* pParams = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams(pEvtMod->GetListaRutas(), false, true);
+							GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams* pParams = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorialParams(pEvtMod->GetListaRutas(), pEvtMod->GetAbrirDespuesDeCargar(), true);
 							pParams->m_informar = false;
 							GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial* pCmd = new GADAPI::ComandoIncluirHistorial::ComandoIncluirHistorial(pParams);
 							GNC::Entorno::Instance()->GetControladorComandos()->ProcessAsync(_Std("Storing in the history..."),pCmd, NULL);
