@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: panelserie.cpp 3714 2011-04-15 13:07:01Z tovar $
+ *  $Id: panelserie.cpp 3985 2011-07-13 12:01:17Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -23,11 +23,15 @@
 #include <main/controllers/controladorlog.h>
 #include <main/controllers/controladorcomandos.h>
 #include <main/controllers/controladoreventos.h>
+#include <main/controllers/controladorpermisos.h>
+#include <main/controllers/controladorhl7.h>
 #include <main/entorno.h>
 #include <main/gui/pacsupload/wxwizarduploadpacs.h>
 #include <commands/comandogenerarthumbnails.h>
 #include <api/ivista.h>
-#include <api/internacionalizacion.h>
+#include <api/dicom/idicommanager.h>
+#include <export/tagsprivadoscomunes.h>
+
 #include <api/icontextoestudio.h>
 
 #include <resources/ginkgoresourcemanager.h>
@@ -279,15 +283,54 @@ namespace GNC {
 			menu.Append(5, _("Open Series with .."));
 			menu.Connect(5,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnAbrirCon),NULL,this);
 			menu.AppendSeparator();
-			wxMenuItem* pMenuSend = new wxMenuItem(&menu, 7, wxString( _("Send to PACS server") ), _("Send to PACS server"), wxITEM_NORMAL );
-			menu.Connect(7,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnUploadPACS),NULL,this);
-			#ifdef __WXMSW__
-			pMenuSend->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
-			#else
-			pMenuSend->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
-			#endif
-			menu.Append(pMenuSend);
-			menu.AppendSeparator();
+				
+			
+			//Do you have to reprocess this series?
+			GNC::GCS::IControladorModulo* pModulo = NULL;
+
+			GNC::ControladorExtensiones::ListaModulos listaModulos = ControladorExtensiones::Instance()->Modulos();
+			for(GNC::ControladorExtensiones::IteradorListaModulos itModulos = listaModulos.begin(); itModulos!= listaModulos.end() && pModulo == NULL; ++itModulos)
+			{
+				if((*itModulos).second->SupportsImportationUID(m_idImportador)) {
+					pModulo = (*itModulos).second;
+					break;
+				}
+			}
+
+			if(pModulo != NULL) {
+				//reprocess integration xml... read xml from first file..
+				std::vector<std::string> rutas = GNC::GCS::ControladorHistorial::Instance()->GetPathsSerieOrdenados(m_uidSerie);
+				GIL::DICOM::IDICOMManager* pManager = GNC::Entorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
+				GIL::DICOM::TipoPrivateTags tagsPrivados(UID_TAGS_PRIVADOS_COMUNES);
+				pManager->CargarFichero(rutas[0]);
+				pManager->CargarTagsPrivados(tagsPrivados);
+				std::string xmlString;
+				if (tagsPrivados.GetTag(TAG_XML_INTEGRACION, xmlString)) {
+					wxMenuItem* pMenuSend = new wxMenuItem(&menu, 8, wxString( _("Reprocess Series") ), _("Reprocess Series"), wxITEM_NORMAL );
+					menu.Connect(8,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnReprocessIntegration),NULL,this);
+					#ifdef __WXMSW__
+					pMenuSend->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoReset());
+					#else
+					pMenuSend->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoReset());
+					#endif
+					menu.Append(pMenuSend);
+					menu.AppendSeparator();
+				}
+				GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pManager);				
+			}
+			//end reprocess		
+
+			if(GNC::GCS::ControladorPermisos::Instance()->Get("core.menu","subir pacs")) {
+				wxMenuItem* pMenuSend = new wxMenuItem(&menu, 7, wxString( _("Send to PACS server") ), _("Send to PACS server"), wxITEM_NORMAL );
+				menu.Connect(7,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnUploadPACS),NULL,this);
+				#ifdef __WXMSW__
+				pMenuSend->SetBitmaps(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
+				#else
+				pMenuSend->SetBitmap(GinkgoResourcesManager::IconosMenus::GetIcoSendToPACS());
+				#endif
+				menu.Append(pMenuSend);
+				menu.AppendSeparator();
+			}
 
 			wxMenuItem* pMenuEliminar = new wxMenuItem(&menu, 3, wxString( _("&Delete from history") ), _("Delete"), wxITEM_NORMAL );
 			menu.Connect(3,wxEVT_COMMAND_MENU_SELECTED,wxCommandEventHandler( PanelSerie::OnEliminar),NULL,this);
@@ -404,17 +447,14 @@ namespace GNC {
 			GNC::GCS::ModoControlador* pModo = NULL;
 
 			GNC::ControladorExtensiones::ListaModulos listaModulos = ControladorExtensiones::Instance()->Modulos();
-			for(GNC::ControladorExtensiones::IteradorListaModulos itModulos = listaModulos.begin(); itModulos!= listaModulos.end() && pModo == NULL && pModulo == NULL; ++itModulos){
-				std::ostringstream os;
-				os<<itModulos->second->GetUID();
-				if(os.str() == m_idImportador){
-					//se busca la vista del modulo q abra este tipo de ficheros
-					for(GNC::GCS::IControladorModulo::IteradorListaModos itModos = (*itModulos).second->GetListaModos().begin(); itModos != (*itModulos).second->GetListaModos().end(); ++itModos){
-						if((*itModos)->SupportsModalityFile(m_idModalidad,m_uidTransferSyntax)) {
-							pModo = (*itModos);
-							pModulo = (*itModulos).second;
-							break;
-						}
+			for(GNC::ControladorExtensiones::IteradorListaModulos itModulos = listaModulos.begin(); itModulos!= listaModulos.end() && pModo == NULL && pModulo == NULL; ++itModulos)
+			{
+				//se busca la vista del modulo q abra este tipo de ficheros
+				for(GNC::GCS::IControladorModulo::IteradorListaModos itModos = (*itModulos).second->GetListaModos().begin(); itModos != (*itModulos).second->GetListaModos().end(); ++itModos){
+					if((*itModos)->SupportsImportationUID(m_idImportador) && (*itModos)->SupportsModalityFile(m_idModalidad,m_uidTransferSyntax)) {
+						pModo = (*itModos);
+						pModulo = (*itModulos).second;
+						break;
 					}
 				}
 			}
@@ -549,6 +589,81 @@ namespace GNC {
 			wiz.ShowModal();
 		}
 
+		void PanelSerie::OnReprocessIntegration(wxCommandEvent &)
+		{
+			int answer = wxMessageBox(_("If you reprocess this series it will be uploaded to PACS server and \nintegration message will be resent to integration engine.\nDo you want to continue?"),_("Open again"), wxYES_NO , GNC::Entorno::Instance()->GetVentanaRaiz());
+			if (answer != wxYES) {
+				return;
+			}
+
+			//darse cuenta si debe abrirse por estudios, en ese caso decirle al padre que se quiere abrir...
+			GNC::GCS::IControladorModulo* pModulo = NULL;
+
+			GNC::ControladorExtensiones::ListaModulos listaModulos = ControladorExtensiones::Instance()->Modulos();
+			for(GNC::ControladorExtensiones::IteradorListaModulos itModulos = listaModulos.begin(); itModulos!= listaModulos.end() && pModulo == NULL; ++itModulos)
+			{
+				if((*itModulos).second->SupportsImportationUID(m_idImportador)) {
+					pModulo = (*itModulos).second;
+					break;
+				}
+			}
+
+			//reprocess integration xml... read xml from first file..
+			std::vector<std::string> rutas = GNC::GCS::ControladorHistorial::Instance()->GetPathsSerieOrdenados(m_uidSerie);
+			GIL::DICOM::IDICOMManager* pManager = GNC::Entorno::Instance()->GetPACSController()->CrearInstanciaDeDICOMManager();
+			GIL::DICOM::TipoPrivateTags tagsPrivados(UID_TAGS_PRIVADOS_COMUNES);
+			pManager->CargarFichero(rutas[0]);
+			pManager->CargarTagsPrivados(tagsPrivados);
+			std::string xmlString;
+			if (!tagsPrivados.GetTag(TAG_XML_INTEGRACION, xmlString)) {
+				wxMessageBox(_("Unable to reprocess this series. This series hasn't been dicomized with Ginkgo CADx."), _("Info"),
+					 wxOK | wxICON_INFORMATION, GNC::Entorno::Instance()->GetVentanaRaiz());
+				GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pManager);
+				return;
+			}
+			GNC::Entorno::Instance()->GetPACSController()->LiberarInstanciaDeDICOMManager(pManager);
+
+			try {
+				GIL::HL7::ControladorHL7 controlador;
+				GNC::GCS::IEntorno::ListaModelosIntegracion& listaModelos = GNC::Entorno::Instance()->GetModelosIntegracion();
+				controlador.ParsearModeloIntegracion(listaModelos,xmlString);
+
+				typedef GNC::GCS::IEntorno::ListaModelosIntegracion::iterator TIteradorModelos;
+				for (TIteradorModelos it = listaModelos.begin(); it != listaModelos.end(); it++) {
+					GnkPtr<GIL::IModeloIntegracion> modelo = (*it);
+					if (modelo->atendido)
+						continue;
+					else
+						modelo->atendido = true;
+					if(modelo->accion == GIL::IModeloIntegracion::TA_Dicomizar) {
+						//se busca el dicomizador del modulo indicado, habra un mapa que transformara sid en uids de modulo
+						std::string uidModulo = controlador.GetUID(modelo->idPlantilla);
+						modelo->UIDModulo = uidModulo;
+						if (GNC::ControladorExtensiones::Instance()->ObtenerModulo(uidModulo) == NULL) {
+							throw GIL::HL7::HL7Exception("No existe el modulo asociado", "Modelo", true);
+						}
+						pModulo->ReprocessIntegration(m_uidSerie, modelo);
+					}
+				}
+			}
+			catch (GIL::HL7::HL7XMLException& ex) {
+				LOG_ERROR("GIL/WF", "Semantic/Sintactic error parsing integration XML: " << ex.GetFullCause());
+				wxMessageBox(_("Semantic/Sintactic error parsing integration XML (see log for details):\n") + wxString::FromUTF8(ex.GetCause().c_str()),_("Error"),wxICON_INFORMATION);
+			}
+			catch (GIL::HL7::HL7Exception& ex1) {
+				LOG_ERROR("GIL/WF", "Error parsing integration XML: " << ex1.GetCause());
+				wxMessageBox(_("Error parsing integration XML:\n") + wxString::FromUTF8(ex1.GetCause().c_str()),_("Error"),wxICON_INFORMATION);
+			}
+			catch (std::exception& ex4) {
+				LOG_ERROR("GIL/WF", "Error executing WorkFlow: " << ex4.what());
+				wxMessageBox(_("Error executing WorkFlow\n") + wxString::FromUTF8(ex4.what()),_("Error"),wxICON_INFORMATION);
+			}
+			catch (...) {
+				LOG_ERROR("GIL/WF", "Error executing WorkFlow: Internal error.");
+				wxMessageBox(_("Error executing WorkFlow\nInternal Error"), _("Error"),wxICON_INFORMATION);
+			}
+		}
+
 		void PanelSerie::Detach(wxWindow* ){}
 
 		void PanelSerie::Eliminar()
