@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: pasoperfilimportacion.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: pasoperfilimportacion.h 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,7 +16,7 @@
 #include "pasosimportacionbase.h"
 
 #include <api/iwizard.h>
-#include <api/icontroladorimportacionpacs.h>
+#include <api/controllers/ipacscontroller.h>
 #include <api/ientorno.h>
 
 #include <string>
