@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: acceptlicensedialog.cpp 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: acceptlicensedialog.cpp 3893 2011-06-21 13:01:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -12,13 +12,13 @@
  *
  */
 #include "acceptlicensedialog.h"
-#include <wx/config.h>
+#include <main/controllers/configurationcontroller.h>
 #include <main/entorno.h>
 #include <api/globals.h>
 #include <main/licencia.h>
 #include <string>
 #include <sstream>
-#include <api/internacionalizacion.h>
+
 
 GNC::GUI::AcceptLicenseDialog::AcceptLicenseDialog(wxWindow* pPadre):GNC::GUI::AcceptLicenseDialogBase(pPadre)
 {
@@ -42,10 +42,7 @@ GNC::GUI::AcceptLicenseDialog::~AcceptLicenseDialog()
 
 void GNC::GUI::AcceptLicenseDialog::OnAceptarClick(wxCommandEvent &event)
 {
-	wxConfigBase * config = wxConfigBase::Get();
-	//se actualiza el fichero de configuracion
-	config->SetPath(wxT("/GinkgoCore/Estacion"));
-	config->Write(wxT("CheckForUpdates"),m_pCheckForUpdates->GetValue());
-	config->Flush();
+	GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/Estacion", "CheckForUpdates", m_pCheckForUpdates->GetValue());
+	GNC::GCS::ConfigurationController::Instance()->Flush();
 	event.Skip(true);
 }
