@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: ventanaprincipal.cpp 3757 2011-04-25 09:23:15Z carlos $
+ *  $Id: ventanaprincipal.cpp 3984 2011-07-13 11:30:41Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -16,7 +16,7 @@
 #include <iostream>
 #include <sstream>
 
-#include <api/internacionalizacion.h>
+
 #include <wx/wx.h>
 #include <wx/aui/aui.h>
 #include <wx/app.h>
@@ -38,6 +38,7 @@
 #include <wx/dnd.h>
 #include <wx/txtstrm.h>
 #include <wx/display.h>
+#include <wx/cmdline.h>
 
 #include <main/gui/mainwindow/ventanaprincipal.h>
 #include <main/panelgrid.h>
@@ -48,7 +49,7 @@
 #include <main/gui/license/licensedialog.h>
 #include <main/gui/license/acceptlicensedialog.h>
 #include <main/gui/import/wxwizardimportacionginkgo.h>
-#include <main/gui/adquisition/dialogoadquisicion.h>
+#include <main/gui/acquisition/dialogoadquisicion.h>
 #include <main/gui/export/wxwizardexportacionginkgo.h>
 #include <main/gui/history/panelhistorial2.h>
 #include <main/gui/paneltags/paneltags.h>
@@ -62,7 +63,7 @@
 #include <api/ivista.h>
 #include <api/icontextoestudio.h>
 #include <api/icontroladormodulo.h>
-#include <api/icontroladorimportacionpacs.h>
+#include <api/controllers/ipacscontroller.h>
 
 #include <main/entorno.h>
 
@@ -77,6 +78,7 @@
 #include <main/controllers/controladorlog.h>
 #include <main/controllers/dcmtk/dicomservers.h>
 #include <main/controllers/xmlrpccontroller.h>
+#include <main/controllers/configurationcontroller.h>
 
 #include <commands/comandopacs.h>
 #include <commands/comandoactualizaciones.h>
@@ -459,24 +461,17 @@ VentanaPrincipal::~VentanaPrincipal()
 //region "Eventos de comprobacion de actualizaciones"
 void VentanaPrincipal::ComprobarActualizaciones()
 {
-	//firstly configuration check is checked
-	wxConfigBase * config = wxConfigBase::Get();
-	config->SetPath(wxT("/GinkgoCore/Estacion"));
 	bool check;
-
-	config->Read(wxT("CheckForUpdates"),&check, true);
+	GNC::GCS::ConfigurationController::Instance()->readBoolGeneral("/GinkgoCore/Estacion", "CheckForUpdates", check, true);
 	if (check) {
 		m_VersionChecked = false;
 		//this is the profile
 		GNC::GCS::Permisos::EstadoPermiso updates = GNC::GCS::ControladorPermisos::Instance()->Get("core.update","check_updates");
 		if (updates) {
-
-			config->SetPath(wxT("/GinkgoCore/LastUpdateDateTime"));
-
 			bool tryCheck = false;
-			wxString lastDateStr;
-			if (config->Read(wxT("LastDate"),&lastDateStr)) {
-
+			std::string lastDateStr;
+			if (GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/LastUpdateDateTime", "LastDate", lastDateStr)) 
+			{
 				GNC::GCS::Permisos::EstadoPermiso period = GNC::GCS::ControladorPermisos::Instance()->Get("core.update","update_period");
 				std::string periodStr = period.ObtenerValor<std::string>();
 				long iPeriod;
@@ -486,7 +481,7 @@ void VentanaPrincipal::ComprobarActualizaciones()
 
 				wxDateTime lastDate;
 
-				lastDate.ParseFormat(lastDateStr.c_str(), wxT("%d/%m/%Y %H:%M:%S"));
+				lastDate.ParseFormat(wxString::FromUTF8(lastDateStr.c_str()), wxT("%d/%m/%Y %H:%M:%S"));
 				if (!lastDate.IsValid()) {
 					lastDate = wxDateTime::Now();
 					lastDate.Subtract( wxDateSpan(0, 0, 0, iPeriod + 1 ) );
@@ -494,20 +489,20 @@ void VentanaPrincipal::ComprobarActualizaciones()
 
 				if (wxDateTime::Now().Subtract(lastDate).GetDays() > iPeriod) {
 					tryCheck = true;
-					GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("CheckUpdates"),
+					GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("Check Updates"),
 						new GNC::ComandoComprobarActualizaciones(new GNC::ComandoComprobarActualizacionesParams(updates.ObtenerValor<std::string>(), false) ), this);
 				}
 
 			} else {
 				//if there is no date in the ini file update will be checked
-				GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("CheckUpdates"),
+				GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("Check Updates"),
 					new GNC::ComandoComprobarActualizaciones(new GNC::ComandoComprobarActualizacionesParams(updates.ObtenerValor<std::string>(), false) ), this);
 				tryCheck = true;
 			}
 
 			if (tryCheck) {
 				//writes date
-				config->Write(wxT("LastDate"), wxDateTime::Now().Format(wxT("%d/%m/%Y %H:%M:%S")));
+				GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/LastUpdateDateTime", "LastDate", std::string(wxDateTime::Now().Format(wxT("%d/%m/%Y %H:%M:%S")).ToUTF8()));
 			}
 		}
 	}
@@ -518,15 +513,13 @@ void VentanaPrincipal::OnDoNotWarnAgainClicked( wxCommandEvent& /*event*/ )
 {
 	if (m_VersionChecked) {
 		wxString valor;
-		wxConfigBase* config = wxConfigBase::Get();
-		config->SetPath(wxT("/GinkgoCore/SkipUpdate"));
 		if (m_pDoNotWarnAgain->GetValue()) {
-			config->Write(wxString::FromUTF8(m_VersionCheck.c_str()), wxT("1"));
+			GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/SkipUpdate", m_VersionCheck, "1");
 		}
 		else{
-			config->Write(wxString::FromUTF8(m_VersionCheck.c_str()), wxT("0"));
+			GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/SkipUpdate", m_VersionCheck, "0");
 		}
-		config->Flush();
+		GNC::GCS::ConfigurationController::Instance()->Flush();
 	}
 
 }
@@ -683,13 +676,6 @@ void VentanaPrincipal::OnExtensionsSupport(wxCommandEvent& /*event*/)
 	}
 }
 
-void VentanaPrincipal::OnLicencia(wxCommandEvent& WXUNUSED(event))
-{
-	GNC::GUI::LicenseDialog* dlg = new GNC::GUI::LicenseDialog(this);
-	wxYield();
-	dlg->ShowModal();
-}
-
 /* Evento de lanzamiento de la comprobacion de actualizaciones */
 void VentanaPrincipal::OnCheckForUpdates(wxCommandEvent& /*event*/)
 {
@@ -699,12 +685,10 @@ void VentanaPrincipal::OnCheckForUpdates(wxCommandEvent& /*event*/)
 		wxMessageBox(_("There is no URL to check updates on the current configuration."), _("Check update error"),wxICON_ERROR);
 	}
 	else {
-		GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("CheckUpdates"),
+		GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("Check Updates"),
 			new GNC::ComandoComprobarActualizaciones(new GNC::ComandoComprobarActualizacionesParams(updates.ObtenerValor<std::string>(), true) ), this);
 
-		wxConfigBase* config = wxConfigBase::Get();
-		config->SetPath(wxT("/GinkgoCore/LastUpdateDateTime"));
-		config->Write(wxT("LastDate"), wxDateTime::Now().Format());
+		GNC::GCS::ConfigurationController::Instance()->writeStringGeneral("/GinkgoCore/LastUpdateDateTime", "LastDate", std::string(wxDateTime::Now().Format().ToUTF8()));
 	}
 }
 
@@ -1418,7 +1402,8 @@ void VentanaPrincipal::EliminarVentana(wxWindow *WXUNUSED(pVentana))
 	throw new std::exception();
 }
 
-void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &) {
+void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &) 
+{	
 	//esto esta aqui porque hasta este punto no esta registrada la herramienta...
 	//panel tags
 	GNC::GCS::IHerramientaPanelTags* pHerramienta = GNC::ControladorHerramientas::Instance()->ObtenerHerramientaConcreta<GNC::GCS::IHerramientaPanelTags>(GNC::GCS::IHerramientaPanelTags::ID);
@@ -1436,36 +1421,69 @@ void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &) {
 		//
 		m_mgr.Update();
 	}
+	
+	//parameters parsing...
+	bool aceptedLicense = false;
+	bool versionParameter = false;
+	wxString pathOfFile = wxEmptyString;
 
-	//aceptacion de la licencia
-	wxConfigBase * config = wxConfigBase::Get();
-	//se actualiza el fichero de configuracion
-	config->SetPath(wxT("/GinkgoCore/Licencia"));
+	int argc = GNC::Entorno::Instance()->GetApp()->argc;
+	wxChar** argv = GNC::Entorno::Instance()->GetApp()->argv;
+	if (argc > 1) {
+		for (int i = 1; i < argc; i++) {
+			wxString param(argv[i]);
 
-	bool aceptada;
-	config->Read(wxT("Aceptada"),&aceptada,false);
-	if(!aceptada) {
-		GNC::GUI::AcceptLicenseDialog dlgLicencia(NULL);
-		wxYield();
-		int answer = dlgLicencia.ShowModal();
-		config->SetPath(wxT("/GinkgoCore/Licencia"));
-		if(answer == wxID_OK) {
-			config->Write(wxT("Aceptada"),true);
-			config->Flush();
-		} else {
-			config->Write(wxT("Aceptada"),false);
-			config->Flush();
-			Close();
-			return;
+			if ( param.CmpNoCase(wxT("-version")) == 0 || param.CmpNoCase(wxT("--version")) == 0 || param.CmpNoCase(wxT("-v")) == 0 ) {
+				versionParameter = true;
+				continue;
+			}
+			if (param.CmpNoCase(wxT("--accepted")) == 0 || param.CmpNoCase(wxT("-a")) == 0) {
+				aceptedLicense = true;
+				continue;
+			}
+			pathOfFile = param;
 		}
 	}
 
-	//si viene un parametro y es un directorio... abrir directamente
-	int argc = GNC::Entorno::Instance()->GetApp()->argc;
-	wxChar** argv = GNC::Entorno::Instance()->GetApp()->argv;
-	if(argc == 2)
+	if (versionParameter) {
+		int version = 0;
+		int subversion = 0;
+		int release = 0;
+		int build = 0;
+		std::string codename;
+
+		GNC::Entorno::Instance()->GetGinkgoVersionAsTuple(&version, &subversion, &release, &build, &codename);
+		GNC::Entorno::FreeInstance();
+		std::cout << version << "." << subversion << "." << release << "." << build << " " << codename.c_str() << std::endl;
+		Close();
+	}
+
+	if (!aceptedLicense) 
 	{
-		EjecutarParametro(wxString(argv[1]), true);
+		//aceptacion de la licencia
+		bool aceptada;
+		GNC::GCS::ConfigurationController::Instance()->readBoolGeneral("/GinkgoCore/Licencia", "Aceptada", aceptada, false);
+		if(!aceptada) {
+			GNC::GUI::AcceptLicenseDialog dlgLicencia(NULL);
+			wxYield();
+			int answer = dlgLicencia.ShowModal();
+			if(answer == wxID_OK) {
+				GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/Licencia", "Aceptada", true);
+				GNC::GCS::ConfigurationController::Instance()->Flush();
+			} else {
+				GNC::GCS::ConfigurationController::Instance()->writeBoolGeneral("/GinkgoCore/Licencia", "Aceptada", false);
+				GNC::GCS::ConfigurationController::Instance()->Flush();
+				Close();
+				return;
+			}
+		}
+	}
+
+
+	//si viene un parametro y es un directorio... abrir directamente
+	if(!pathOfFile.empty())
+	{
+		EjecutarParametro(pathOfFile, true);
 	} else {
 		Login();
 	}
@@ -1750,6 +1768,8 @@ void VentanaPrincipal::RefrescarMenus()
 		pMenuArchivo->AppendSeparator();
 		if(GNC::GCS::ControladorPermisos::Instance()->Get("core.menu","subir pacs")) {
 			pMenuArchivo->Append(m_pMenuSubirPacs);
+		} else { 
+			delete m_pMenuSubirPacs;
 		}
 		pMenuArchivo->Append( m_pMenuExportar );
 		pMenuArchivo->AppendSeparator();
@@ -1778,7 +1798,6 @@ void VentanaPrincipal::RefrescarMenus()
 
 		//ayuda
 		wxMenuItem*  pMenuOnlineHelp = new wxMenuItem( pMenuAyuda, ID_ONLINE_MANUAL, wxString( _("Ginkgo CADx Online Manual ...") ), _("Ginkgo CADx Online Manual ..."), wxITEM_NORMAL );
-		wxMenuItem*  m_pMenuLicencia = new wxMenuItem( pMenuAyuda, ID_LICENCIA, wxString( _("License ...") ), _("Ginkgo CADx License ..."), wxITEM_NORMAL );
 		wxMenuItem*  m_pMenuCheckUpdates = new wxMenuItem( pMenuAyuda, ID_CHECK_UPDATES, wxString( _("Check for updates") ), _("Check for newest versions"), wxITEM_NORMAL );
 		wxMenuItem*  pMenuOnlineSupport = new wxMenuItem( pMenuAyuda, ID_ONLINE_SUPPORT, wxString( _("Need support ...") ), _("Need support ..."), wxITEM_NORMAL );
 		wxMenuItem*  pMenuExtSupport = new wxMenuItem( pMenuAyuda, ID_EXTENSIONS_SUPPORT, wxString( _("Get Extensions ...") ), _("Get Extensions ..."), wxITEM_NORMAL );
@@ -1795,14 +1814,6 @@ void VentanaPrincipal::RefrescarMenus()
 		#endif
 
 		pMenuAyuda->Append( pMenuOnlineHelp );
-		if(GNC::GCS::ControladorPermisos::Instance()->Get("core.menu","licencia")) {
-			pMenuAyuda->AppendSeparator();
-			pMenuAyuda->Append( m_pMenuLicencia );
-			this->Connect( m_pMenuLicencia->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnLicencia ) );
-		} else {
-			delete m_pMenuLicencia;
-			m_pMenuLicencia = NULL;
-		}
 		pMenuAyuda->AppendSeparator();
 		pMenuAyuda->Append( pMenuOnlineSupport );
 		pMenuAyuda->Append( pMenuExtSupport );
@@ -2454,12 +2465,9 @@ void VentanaPrincipal::ProcesarEvento(GNC::GCS::Eventos::IEvento *pEvt)
 						return;
 					}
 
-					wxString valor;
-
-					wxConfigBase* config = wxConfigBase::Get();
-					config->SetPath(wxT("/GinkgoCore/SkipUpdate"));
-					config->Read(wxString::FromUTF8(m_VersionCheck.c_str()), &valor, wxT("0"));
-					if (valor == wxT("1") && !pE->Informar()) {
+					std::string valor;
+					GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/SkipUpdate", m_VersionCheck, valor, "0");
+					if (valor == "1" && !pE->Informar()) {
 						return;
 					}
 
@@ -2470,7 +2478,7 @@ void VentanaPrincipal::ProcesarEvento(GNC::GCS::Eventos::IEvento *pEvt)
 					m_pHipervinculoActualizacion->SetURL(wxString::FromUTF8(pE->GetURL().c_str()));
 					m_pHipervinculoActualizacion->SetToolTip(wxString::FromUTF8(pE->GetDescription().c_str()));
 
-					if (valor == wxT("1")) {
+					if (valor == "1") {
 						m_pDoNotWarnAgain->SetValue(true);
 					}
 					else {
