@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: selectfiles.h 3669 2011-04-11 10:59:33Z tovar $
+ *  $Id: selectfiles.h 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -14,7 +14,7 @@
 #pragma once
 #include <api/iwizard.h>
 #include <api/ivista.h>
-#include <api/icontroladorimportacionpacs.h>
+#include <api/controllers/ipacscontroller.h>
 #include "uploadpacsbase.h"
 
 #include <string>
