@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: paneltags.h 3526 2011-03-16 19:56:19Z carlos $
+ *  $Id: paneltags.h 3830 2011-05-06 13:30:18Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -13,7 +13,7 @@
  */
 #pragma once
 #include "paneltagsbase.h"
-#include <api/icontroladorimportacionpacs.h>
+#include <api/controllers/ipacscontroller.h>
 #include <export/iherramientapaneltags.h>
 #include <wx/propgrid/propgrid.h>
 #include <wx/propgrid/advprops.h>
