@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: printmanager.cpp 3746 2011-04-19 10:41:32Z carlos $
+ *  $Id: printmanager.cpp 3935 2011-07-07 09:17:38Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -337,10 +337,10 @@ namespace GNC {
 
 				gbSizerPpal->Add( pPanelContenido, wxGBPosition( 0, 0 ), wxGBSpan( 1, 1 ), wxEXPAND );
 
-				SubTitledPanelSeparator* pSepVertical = new SubTitledPanelSeparator(pPanelFondo);
+				SubTitledPanelSeparatorV* pSepVertical = new SubTitledPanelSeparatorV(pPanelFondo);
 				gbSizerPpal->Add( pSepVertical, wxGBPosition( 1, 0 ), wxGBSpan( 1, 1 ), wxEXPAND );
 
-				SubTitledPanelSeparator* pSepHorizontal = new SubTitledPanelSeparator(pPanelFondo);
+				SubTitledPanelSeparatorH* pSepHorizontal = new SubTitledPanelSeparatorH(pPanelFondo);
 				gbSizerPpal->Add( pSepHorizontal, wxGBPosition( 0, 1 ), wxGBSpan( 1, 1 ), wxEXPAND );
 
 				m_pPanelPrevisualizacion = new SubTitledPanel(pPanelFondo, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL);
