@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: thumbnailctrl.cpp 3629 2011-03-28 13:10:09Z tovar $
+ *  $Id: thumbnailctrl.cpp 3822 2011-05-04 08:34:50Z carlos $
  *  Ginkgo CADx Project
  *
  *
@@ -59,9 +59,11 @@ DEFINE_EVENT_TYPE(wxEVT_COMMAND_THUMBNAIL_RIGHT_CLICK)
 DEFINE_EVENT_TYPE(wxEVT_COMMAND_THUMBNAIL_LEFT_DCLICK)
 DEFINE_EVENT_TYPE(wxEVT_COMMAND_THUMBNAIL_RETURN)
 
-IMPLEMENT_CLASS( wxThumbnailCtrl, wxScrolledWindow )
-IMPLEMENT_CLASS( wxThumbnailItem, wxObject )
-IMPLEMENT_CLASS( wxThumbnailEvent, wxNotifyEvent )
+IMPLEMENT_DYNAMIC_CLASS( wxThumbnailCtrl, wxScrolledWindow )
+IMPLEMENT_DYNAMIC_CLASS( wxThumbnailItem, wxObject )
+IMPLEMENT_DYNAMIC_CLASS( wxThumbnailEvent, wxNotifyEvent )
+IMPLEMENT_DYNAMIC_CLASS( wxImageThumbnailItem, wxThumbnailItem)
+IMPLEMENT_DYNAMIC_CLASS( wxMemoryImageThumbnailItem, wxThumbnailItem)
 
 BEGIN_EVENT_TABLE( wxThumbnailCtrl, wxScrolledWindow )
     EVT_PAINT(wxThumbnailCtrl::OnPaint)
@@ -1630,7 +1632,7 @@ wxSize wxThumbnailCtrl::DoGetBestSize() const
  * wxImageThumbnailItem
  */
 
-IMPLEMENT_CLASS(wxImageThumbnailItem, wxThumbnailItem)
+
 
 /// Draw the item
 bool wxImageThumbnailItem::Draw(wxDC& dc, wxThumbnailCtrl* WXUNUSED(ctrl), const wxRect& rect, int WXUNUSED(style))
@@ -1685,8 +1687,6 @@ bool wxImageThumbnailItem::Load(wxThumbnailCtrl* ctrl, bool forceLoad)
  * wxImageThumbnailItem
  */
 
-IMPLEMENT_CLASS(wxMemoryImageThumbnailItem, wxThumbnailItem)
-
 /// Draw the item
 bool wxMemoryImageThumbnailItem::Draw(wxDC& dc, wxThumbnailCtrl* WXUNUSED(ctrl), const wxRect& rect, int WXUNUSED(style))
 {
