@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: comandodicomizacionintegracion.cpp 3698 2011-04-14 12:38:49Z carlos $
+ *  $Id: comandodicomizacionintegracion.cpp 3964 2011-07-11 22:17:46Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -13,29 +13,37 @@
  */
 //#define _GINKGO_TRACE
 //#define DUMP_IMAGENES
-#include <api/globals.h>
+
 #include <sstream>
-#include "comandodicomizacionintegracion.h"
 #include <map>
 #include <cmath>
+
 #include <wx/msgdlg.h>
 #include <wx/filename.h>
 #include <wx/dir.h>
 #include <wx/file.h>
-#include <wx/confbase.h>
 #include <wx/xml/xml.h>
 #include <wx/mstream.h>
+
+#include <api/globals.h>
+
 #include <api/icontroladoreventos.h>
 #include <api/icontroladorcomandos.h>
-#include <api/icontroladorimportacionpacs.h>
-#include <api/idicomizador.h>
-#include <api/idicommanager.h>
-#include <eventos/eventosginkgo.h>
+#include <api/controllers/ipacscontroller.h>
+
+#include <api/dicom/idicomizador.h>
+#include <api/dicom/idicommanager.h>
+
+#include <main/controllers/controladorlog.h>
+
 #include <commands/comandopacs.h>
 #include <commands/comandoavisarficheros.h>
-#include <api/internacionalizacion.h>
+
+#include <eventos/eventosginkgo.h>
+
 #include <export/tagsprivadoscomunes.h>
-#include <main/controllers/controladorlog.h>
+
+#include "comandodicomizacionintegracion.h"
 
 #define IDC_DICOMIZACION_INTEGRACION           2030
 #define IDC_SUBCOMANDO_ADD_HISTORIAL           2031
@@ -234,7 +242,7 @@ namespace GNKVisualizator {
 		{
 			bool esElPrimero=true;
 
-			GIL::DICOM::IControladorImportacionPACS* pCI = m_pIntegracionParams->m_pEntorno->GetControladorImportacionPACS();
+			GIL::DICOM::IPACSController* pCI = m_pIntegracionParams->m_pEntorno->GetPACSController();
 
 			int instanceNumber = 0;
 
@@ -380,15 +388,15 @@ namespace GNKVisualizator {
 
 					//nos falta el uid de la imagen...
 					std::string idPaciente,uidEstudio,uidSerie,uidImagen;
-					pDICOMManager= m_pIntegracionParams->m_pEntorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+					pDICOMManager= m_pIntegracionParams->m_pEntorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 					pDICOMManager->CargarFichero(pathOrigenStd);
 					pDICOMManager->GetTag(0x0010,0x0020,idPaciente);
 					pDICOMManager->GetTag(0x0020,0x000d,uidEstudio);
 					pDICOMManager->GetTag(0x0020,0x000e,uidSerie);
 					pDICOMManager->GetTag(0x0008,0x0018,uidImagen);
-					m_pIntegracionParams->m_pEntorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+					m_pIntegracionParams->m_pEntorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 					//se pilla el path
-					correcto = correcto && m_pIntegracionParams->m_pEntorno->GetControladorImportacionPACS()->GetRutaImagen(idPaciente,uidEstudio,uidSerie,uidImagen,pathDestinoStd);
+					correcto = correcto && m_pIntegracionParams->m_pEntorno->GetPACSController()->GetRutaImagen(idPaciente,uidEstudio,uidSerie,uidImagen,pathDestinoStd);
 					destinoWx = FROMPATH(pathDestinoStd);
 
 					correcto = correcto && wxCopyFile(pathOrigenWx,destinoWx,true);
