@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: visualizatorcontroller.cpp 3685 2011-04-13 06:16:18Z tovar $
+ *  $Id: visualizatorcontroller.cpp 3963 2011-07-11 14:03:51Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -15,7 +15,6 @@
 #include <wx/notebook.h>
 #include <wx/dir.h>
 #include <wx/file.h>
-#include <wx/config.h>
 #include <set>
 #include "visualizatorcontroller.h"
 
@@ -23,8 +22,6 @@
 #include "../herramientas/herramientaoverlays.h"
 #include "../herramientas/reconstructiontool.h"
 
-#include "../../recursos/plantillas/plantillasaprimresourcemanager.h"
-
 #include "../dialogos/contenedorherramientas.h"
 #include "../dialogos/importacion/pasodatosgenerales.h"
 #include "../dialogos/importacion/datospersistentesimportacion.h"
@@ -36,32 +33,34 @@
 
 #include <api/ientorno.h>
 #include <api/ivista.h>
-#include <api/imodelodicom.h>
+#include <api/dicom/imodelodicom.h>
 #include <api/icontroladorcarga.h>
-#include <api/icontroladorhistorial.h>
+#include <main/controllers/controladorhistorial.h>
 
 #include <api/icontroladorpermisos.h>
 
 #include <api/icontroladorherramientas.h>
 
-#include <api/icontroladorimportacionpacs.h>
+#include <api/controllers/ipacscontroller.h>
 #include <api/icontroladorvistas.h>
 
 #include <api/icontroladorcarga.h>
 #include <main/controllers/controladorcarga.h>
+#include <main/controllers/controladorcomandos.h>
+#include <commands/comandopacs.h>
 
 #include <vector>
 #include <string>
 #include <sstream>
 #include <iostream>
-#include <api/internacionalizacion.h>
+
 #include <api/icontroladorinternacionalizacion.h>
 #include "../../recursos/aprimresourcemanager.h"
 #include "../exportacion/tagsprivados.h"
 
 
 /* Constructor */
-GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::GCS::IEntorno* pEntorno) : GNC::GCS::IControladorModulo(pEntorno, UID_APRIM,0, "atencionprimaria")
+GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::GCS::IEntorno* pEntorno) : GNC::GCS::IControladorModulo(pEntorno, SID_APRIM,0)
 {
 	//primero de todo registramos nuestro catalogo para la internacionalizacion de las cadenas
 	{
@@ -70,7 +69,6 @@ GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::G
 
 	//registramos los permisos
 	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"), "dicomizador",_Std("Simple importation of images"),false, "", true);
-	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"),"plantillas",_Std("Basic templates"), false, "", true);
 	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"),"vista2d",_Std("Medical viewer"), false, "", true);
 	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"),"waveform",_Std("Waveform viewer"), false, "", true);
 	m_pEntorno->GetControladorPermisos()->AddDefinicionPermiso("atencionprimaria",_Std("Ginkgo CADx viewer"),"reconstruction",_Std("3D Reconstruction"), false, "", true);
@@ -86,6 +84,7 @@ GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::G
 
 	m_pEntorno = pEntorno;
 	m_Nombre = VISUALIZATOR_DESCRIPTION;
+	m_ImporterDescription = _Std("Default importer");
 	m_CopyRight = "(c) 2009 MetaEmotion S.L.";
 	m_Author = "MetaEmotion S.L.";
 	m_VersionMayor   = VISUALIZATOR_VERSION;
@@ -97,7 +96,7 @@ GNKVisualizator::ControladorAtencionPrimaria::ControladorAtencionPrimaria(GNC::G
 	m_Version = oversion.str();
 
 	// Codigos LOINC de los informes de A. Primaria.
-	m_ListaInformes.push_back(GNC::GCS::IdHL7("TUID" + m_SID, "0", _Std("Ginkgo CADx visualizator Report"), "LN", "", "","v1.0"));
+	m_ListaInformes.push_back(GNC::GCS::IdHL7("TUID" + m_UID, "0", _Std("Ginkgo CADx visualizator Report"), "LN", "", "","v1.0"));
 
 
 	// Codigos LOINC de los Estudios que genera A. Primaria
@@ -167,6 +166,7 @@ GNKVisualizator::ControladorAtencionPrimaria::~ControladorAtencionPrimaria()
 
 void GNKVisualizator::ControladorAtencionPrimaria::RegistrarVistas()
 {
+	int idModo = 0;
 	GNC::GCS::ModoControlador::TipoListaModalidades listaModalidades;
 	//TODO meter las modalidades que soporta...
 	listaModalidades.push_back(std::string("MR")); //resonancia
@@ -218,18 +218,29 @@ void GNKVisualizator::ControladorAtencionPrimaria::RegistrarVistas()
 	listaModalidades.push_back(std::string("BDUS"));//Bone Densitometry (ultrasound)
 	listaModalidades.push_back(std::string("BMD")); //Bone Densitometry (X-Ray)
 
+	GNC::GCS::ModoControlador::TipoListaUIDsImportacion listaUIDsImportacion;
+	listaUIDsImportacion.push_back(UID_APRIM);
+
 	if(m_pEntorno->GetControladorPermisos()->Get("atencionprimaria", "vista2d")) {
-		m_ListaModos.push_back(new GNC::GCS::ModoControlador(0, _Std("Medical Image Viewer"), listaModalidades, true));
+		m_ListaModos.push_back(new GNC::GCS::ModoControlador(idModo++, _Std("Medical Image Viewer"), listaModalidades, listaUIDsImportacion, true));
 	}
 
 	listaModalidades.clear();
 	listaModalidades.push_back(std::string("ECG")); //Electrocardiography
 	listaModalidades.push_back(std::string("HD")); //Hemodynamic Waveform
+
+	listaUIDsImportacion.clear();
 	if(m_pEntorno->GetControladorPermisos()->Get("atencionprimaria", "waveform")) {
-		m_ListaModos.push_back(new GNC::GCS::ModoControlador(1, _Std("Waveform viewer"), listaModalidades, true));
+		m_ListaModos.push_back(new GNC::GCS::ModoControlador(idModo++, _Std("Waveform viewer"), listaModalidades, listaUIDsImportacion, true));
 	}
 }
 
+
+bool GNKVisualizator::ControladorAtencionPrimaria::SupportsImportationUID(const std::string &importationUID)
+{
+	return (importationUID == UID_APRIM);
+}
+
 /* Abre un estudio de manera no interactiva desde un directorio y devuelve su controlador específico */
 GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::AbrirVista(int modo, ListaDescriptoresSerie& series, const std::string& uidEstudioDiagnostico)
 {
@@ -300,7 +311,7 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::AbrirVista(int m
 			pVentanaPadre = pCtrlVistas->GetRootWindow();
 			pCtrlVistas->Freeze();
 			try{
-				if (modo == m_ListaModos[0]->GetId()) {
+				if (m_ListaModos[modo]->GetDescripcion() == _Std("Medical Image Viewer")) {
 					wxWindowDisabler disabler;
 					InsertarPaneles();
 					GnkPtr<GNKVisualizator::VisualizatorStudy> estudio = new GNKVisualizator::VisualizatorStudy();
@@ -311,7 +322,7 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::AbrirVista(int m
 					estudio->InicializarContextoEstudio(rutas, uidDiagnosticoSeleccionado, GNC::GCS::IContextoEstudio::TMF_UNDiagnostico);
 					pVista = new GNKVisualizator::Vista2D(estudio);
 					pCtrlVistas->Registrar(pVista);
-				} else if (modo == m_ListaModos[1]->GetId()) {
+				} else if (m_ListaModos[modo]->GetDescripcion() == _Std("Waveform viewer")) {
 					wxWindowDisabler disabler;
 					InsertarPaneles();
 					GnkPtr<GNKVisualizator::ECGStudy> estudio = new GNKVisualizator::ECGStudy();
@@ -390,16 +401,6 @@ bool GNKVisualizator::ControladorAtencionPrimaria::SoportaImportacion() const
 	return m_pEntorno->GetControladorPermisos()->Get("atencionprimaria", "dicomizador");
 }
 
-GNKVisualizator::ControladorAtencionPrimaria::TipoListaPlantillas& GNKVisualizator::ControladorAtencionPrimaria::GetPlantillas(){
-	if(m_pEntorno->GetControladorPermisos()->Get("dermatologia","plantillas")) {
-		if(m_listaPlantillas.size() == 0){
-		}
-	} else {
-		m_listaPlantillas.clear();
-	}
-	return m_listaPlantillas;
-}
-
 void GNKVisualizator::ControladorAtencionPrimaria::GetPasosImportacion(IWizard* pWizard,std::list<IPasoWizard*> &listaPasos, wxWindow* pParent, std::string &dirTemporal, GnkPtr<GIL::IModeloIntegracion> pModeloIntegracion){
 	GNKVisualizator::GUI::TipoWizardImportacion* datosPersistentes = new GNKVisualizator::GUI::TipoWizardImportacion(pModeloIntegracion);
 
@@ -451,3 +452,44 @@ void GNKVisualizator::ControladorAtencionPrimaria::OcultarPaneles(bool izquierdo
 }
 //endregion
 
+void GNKVisualizator::ControladorAtencionPrimaria::ReprocessIntegration(const std::string& uidSeries, GnkPtr<GIL::IModeloIntegracion> pIntegrationModel)
+{	
+	//reprocess integration flow...
+	std::vector<std::string> rutas = m_pEntorno->GetControladorHistorial()->GetPathsSerieOrdenados(uidSeries);
+	GnkPtr<GNKVisualizator::VisualizatorStudy> estudio = new GNKVisualizator::VisualizatorStudy();
+	estudio->ListaUIDsSerie.push_back(uidSeries);
+	estudio->Entorno = m_pEntorno;
+	estudio->Modulo = this;
+	estudio->VentanaPadre = NULL;
+	estudio->InicializarContextoEstudio(rutas, "", GNC::GCS::IContextoEstudio::TMF_UNDiagnostico);
+
+	
+	//recreate evidences...
+	std::string strTmp0, strTmp1;
+	pIntegrationModel->Evidencias.clear();
+	estudio->SetIndiceActivo(0);
+	estudio->GetTagImagenActiva("0020|000d", strTmp0);//uid study
+	estudio->GetTagImagenActiva("0008|0050", strTmp1);//accession
+	GIL::IModeloEvidenciaEstudio evidenciaEstudioDicomizado("EstudioOriginal", strTmp0, strTmp1);
+
+	estudio->GetTagImagenActiva("0020|000e", strTmp0);//uid series
+	GIL::IModeloEvidenciaSerie evidenciaSerie("SerieOriginal", strTmp0);
+	for (int i = 0; i < estudio->GetNumeroCortes(); ++i) {
+		estudio->SetIndiceActivo(i);
+		estudio->GetTagImagenActiva("0008|0018", strTmp0);//sop instance
+		estudio->GetTagImagenActiva("0008|0016", strTmp1);//sop class
+
+		GIL::IModeloEvidenciaImagen evidenciaImagen("Imagen", strTmp0, strTmp1);
+		evidenciaSerie.ListaImagenes.push_back(evidenciaImagen);
+	}
+
+	evidenciaEstudioDicomizado.ListaSeries.push_back(evidenciaSerie);
+	pIntegrationModel->Evidencias.push_back(evidenciaEstudioDicomizado);
+	//
+	GADAPI::ComandoPACSParams * pParams = new ::GADAPI::ComandoPACSParams(pIntegrationModel->PACSAlmacenamiento, rutas, pIntegrationModel);
+	pParams->m_informar = false;
+	GADAPI::ComandoPACS * pCmd = new ::GADAPI::ComandoPACS(pParams);
+	GNC::GCS::ControladorComandos::Instance()->ProcessAsync(_Std("Uploading..."), pCmd, NULL);	
+	//
+}
+
