@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: pasodatosgenerales.cpp 3715 2011-04-15 13:11:53Z carlos $
+ *  $Id: pasodatosgenerales.cpp 3893 2011-06-21 13:01:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -11,7 +11,11 @@
  *
  *
  */
-#include <api/ientorno.h>
+
+#include <string>
+#include <sstream>
+#include <cmath>
+
 #include <wx/msgdlg.h>
 #include <wx/filedlg.h>
 #include <wx/valtext.h>
@@ -20,24 +24,23 @@
 #include <wx/filename.h>
 #include <wx/dir.h>
 #include <wx/msgdlg.h>
-#include <wx/confbase.h>
-#include <api/idicommanager.h>
-#include <api/ientorno.h>
-#include <string>
-#include <sstream>
-#include <cmath>
+#include <main/controllers/configurationcontroller.h>
 
+#include <api/ientorno.h>
+
+#include <api/dicom/idicommanager.h>
 
 #include <api/icontroladorcomandos.h>
+
 #include <commands/comandopacs.h>
 
-#include "pasodatosgenerales.h"
-#include <api/internacionalizacion.h>
 #include <export/tagsprivadoscomunes.h>
+
 #include "../../comandos/comandodicomizacionintegracion.h"
-#include <api/icontroladorcomandos.h>
 #include "../../exportacion/tagsprivados.h"
 
+#include "pasodatosgenerales.h"
+
 namespace GNKVisualizator {
 	namespace GUI {
 
@@ -291,11 +294,9 @@ namespace GNKVisualizator {
 			std::string tag;
 
 			//institucion
-			wxString wxTmp;
 			if(m_pDatosPersistentes->NombreCentro == "" ){
-				wxConfigBase::Get()->Read(wxT("/GinkgoCore/Estacion/CentroNombre"),&wxTmp,wxEmptyString);
-				if(wxTmp != wxEmptyString){
-					base.tags[std::string("0008|0080")] = std::string(wxTmp.ToUTF8());
+				if (GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion","CentroNombre",tag)) {
+					base.tags[std::string("0008|0080")] = tag;
 				}
 			} else {
 				base.tags[std::string("0008|0080")] = m_pDatosPersistentes->NombreCentro;
@@ -303,9 +304,8 @@ namespace GNKVisualizator {
 
 			//nombre del medico responsable de la institucion
 			if(m_pDatosPersistentes->NombreMedico == ""){
-				wxConfigBase::Get()->Read(wxT("/GinkgoCore/Estacion/NombreMedico"),&wxTmp,wxEmptyString);
-				if(wxTmp != wxEmptyString){
-					base.tags[std::string("0008|0090")] = std::string(wxTmp.ToUTF8());
+				if (GNC::GCS::ConfigurationController::Instance()->readStringUser("/GinkgoCore/Estacion","NombreMedico",tag)) {
+					base.tags[std::string("0008|0090")] = tag;
 				}
 			} else {
 				base.tags[std::string("0008|0090")] = m_pDatosPersistentes->NombreMedico;
@@ -453,7 +453,7 @@ namespace GNKVisualizator {
 						std::string filePath(fPath.ToUTF8());
 
 						//leer dicom...
-						GIL::DICOM::IDICOMManager*	pDICOMManager= m_pEntorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+						GIL::DICOM::IDICOMManager*	pDICOMManager= m_pEntorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 						GIL::DICOM::TipoJerarquia base;
 						pDICOMManager->CargarFichero(filePath, base);
 
@@ -521,7 +521,7 @@ namespace GNKVisualizator {
 							m_pDatosPersistentes->PacienteSexo=tag;
 						}
 
-						m_pEntorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+						m_pEntorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 
 						//EnableComponents(false);
 					} else {
@@ -581,7 +581,7 @@ namespace GNKVisualizator {
 					std::string filePath(fPath.ToUTF8());
 
 					//leer dicom...
-					GIL::DICOM::IDICOMManager*	pDICOMManager= m_pEntorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+					GIL::DICOM::IDICOMManager*	pDICOMManager= m_pEntorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 					GIL::DICOM::TipoJerarquia base;
 					pDICOMManager->CargarFichero(filePath, base);
 					std::string tag;
@@ -666,7 +666,7 @@ namespace GNKVisualizator {
 						m_pDatosPersistentes->PacienteSexo=tag;
 					}
 
-					m_pEntorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+					m_pEntorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 
 					//EnableComponents(false);
 				} else {
