@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: ecgstudy.cpp 3763 2011-04-25 12:07:55Z carlos $
+ *  $Id: ecgstudy.cpp 3893 2011-06-21 13:01:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -17,22 +17,22 @@
 #include <wx/xml/xml.h>
 #include <wx/file.h>
 #include <wx/filename.h>
-#include <wx/confbase.h>
 #include <wx/mstream.h>
 #include <wx/tokenzr.h>
 
 #include <api/globals.h>
 //#include <api/filename.h>
-#include <api/icontroladorherramientas.h>
 #include <api/ientorno.h>
+#include <api/icontroladorherramientas.h>
+
 #include <main/controllers/controladorlog.h>
 
-#include <api/idicommanager.h>
-#include <api/idicomizador.h>
 #include <api/icontroladorcarga.h>
 #include <api/imodelointegracion.h>
 #include <api/icontroladorhistorial.h>
-#include <api/internacionalizacion.h>
+
+#include <api/dicom/idicommanager.h>
+#include <api/dicom/idicomizador.h>
 
 #include "ecgstudy.h"
 
@@ -490,7 +490,7 @@ void GNKVisualizator::ECGStudy::LoadChannels()
 		ECGFiles[IndiceFicheroActivo] = ecgFile;
 		
 		GnkPtr<GIL::DICOM::TipoJerarquia> base(new GIL::DICOM::TipoJerarquia());
-		GIL::DICOM::IDICOMManager* pDICOMManager = Entorno->GetControladorImportacionPACS()->CrearInstanciaDeDICOMManager();
+		GIL::DICOM::IDICOMManager* pDICOMManager = Entorno->GetPACSController()->CrearInstanciaDeDICOMManager();
 
 		GIL::DICOM::TipoMetaInfo metaInfo;
 
@@ -508,10 +508,10 @@ void GNKVisualizator::ECGStudy::LoadChannels()
 			pDICOMManager->CargarFichero(GetRutaDeImagenActiva(), *base, false);
 			pDICOMManager->FindTag(0x5400, 0x1010, tag);
 
-			Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+			Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 		}
 		else {
-			Entorno->GetControladorImportacionPACS()->LiberarInstanciaDeDICOMManager(pDICOMManager);
+			Entorno->GetPACSController()->LiberarInstanciaDeDICOMManager(pDICOMManager);
 			return;
 		}
 
