@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: license.h 3667 2011-04-11 08:58:02Z tovar $
+ *  $Id: license.h 3890 2011-06-16 06:23:00Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -13,14 +13,18 @@
  */
 #pragma once
 
+//dicomizator
+#define UID_APRIM "METAEMOTION GINKGO RX"
+//module
+#define SID_APRIM "METAEMOTION_GINKGO_RX"
+//sid extension
+#define VISUALIZATOR_SID _Std("Visualizator")
 
-#define VISUALIZATOR_SID _Std("GNKVisualizator")
-
-#define VISUALIZATOR_VERSION     1
-#define VISUALIZATOR_SUB_VERSION 0
+#define VISUALIZATOR_VERSION     2
+#define VISUALIZATOR_SUB_VERSION 4
 #define VISUALIZATOR_SUB_RELEASE 0
 #define VISUALIZATOR_CODENAME    "final"
 #define VISUALIZATOR_COPYRIGHT   " 2011"
-#define VISUALIZATOR_DESCRIPTION _Std("Visualization Module")
+#define VISUALIZATOR_DESCRIPTION _Std("Visualizator Extension")
 #define VISUALIZATOR_PROVIDER "MetaEmotion S.L."
 
