@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: vista2d.cpp 3663 2011-04-08 09:37:56Z tovar $
+ *  $Id: vista2d.cpp 3834 2011-05-10 07:42:57Z carlos $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -24,8 +24,8 @@
 #include <api/icontroladorherramientas.h>
 #include <api/icontroladorvistas.h>
 #include <api/icontroladorcarga.h>
-#include <api/idicommanager.h>
-#include <api/idicomizador.h>
+#include <api/dicom/imodelodicom.h>
+#include <api/dicom/idicomizador.h>
 #include <api/icontroladorpermisos.h>
 #include <eventos/eventosginkgo.h>
 
@@ -52,7 +52,7 @@
 #include "../wxvtk/gvistacompleja.h"
 #include "../wxvtk/gvistasimple.h"
 #include "../dialogos/contenedorherramientas.h"
-#include <api/internacionalizacion.h>
+
 
 
 #define TAG_WIDGETS					    0xb;
