@@ -1,6 +1,6 @@
 /*
  *  
- *  $Id: gvistacompleja.cpp 3748 2011-04-20 10:38:38Z carlos $
+ *  $Id: gvistacompleja.cpp 3893 2011-06-21 13:01:56Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -20,7 +20,6 @@
 
 #include <wx/msgdlg.h>
 #include <wx/menu.h>
-#include <wx/config.h>
 
 #include "../eventos/visualizatorevents.h"
 #include <api/icontroladorherramientas.h>
@@ -71,7 +70,7 @@
 #include <widgets/wanotacionesquina.h>
 
 #include <hackimageactor.h>
-#include <api/internacionalizacion.h>
+
 
 #include "reconstruction/endoscopy.h"
 #include "reconstruction/mpr3d.h"
