@@ -1,6 +1,6 @@
 /*
  *
- *  $Id: gvistasimple.cpp 3663 2011-04-08 09:37:56Z tovar $
+ *  $Id: gvistasimple.cpp 3901 2011-06-29 11:20:49Z tovar $
  *  Ginkgo CADx Project
  *
  *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
@@ -20,7 +20,7 @@
 
 #include <wx/msgdlg.h>
 #include <wx/menu.h>
-#include <wx/config.h>
+#include <main/controllers/configurationcontroller.h>
 
 #include "../eventos/visualizatorevents.h"
 #include <api/icontroladorherramientas.h>
@@ -47,7 +47,7 @@
 
 #include <widgets/openglhelper.h>
 #include <hackimageactor.h>
-#include <api/internacionalizacion.h>
+
 
 class GVtkObserver: public vtkCommand
 {
@@ -510,15 +510,12 @@ std::string GVistaSimple::GetBottomRightAnnotation(GNC::GCS::Contexto3D* c) {
 	if (str.size() == 6) {
 		os << str.substr(0, 2).c_str() << ":";
 	} else {
-		wxConfigBase* config = wxConfigBase::Get();
-		config->SetPath(wxT("/GinkgoCore/Estacion"));
+		//institucion
+		std::string tag;
+		GNC::GCS::ConfigurationController::Instance()->readStringGeneral("/GinkgoCore/Estacion", "CentroNombre", tag);
 
-		wxString valor;
-		config->Read(wxT("CentroNombre"),&valor,wxT(""));
-		std::string centro(valor.ToUTF8());
-
-		if (!centro.empty()) {
-			os << centro.c_str() << std::endl;
+		if (!tag.empty()) {
+			os << tag.c_str() << std::endl;
 		}
 	}
 
@@ -563,7 +560,6 @@ std::string GVistaSimple::GetAnotacionPosicion(GNC::GCS::Vector* pPosicion)
 		if( scalar ) {
 			bool primero = true;
 			for(int i = 0; i<ViewImage2D->GetNumberOfComponents(); i++) {
-
 				switch (ViewImage2D->GetInput()->GetScalarType()) {
 					case VTK_DOUBLE:
 						value = (((double*)scalar)[i]);
